@@ -1,5 +1,8 @@
-/* Suffix for config filenames */
-#define FVWMRC ".fvwm2rc"
+/* Name of config filenames in FVWM_USERDIR and FVWM_DATADIR */
+#define FVWM_CONFIG "config"
+
+/* Suffix for old (to be deprecated) config filenames */
+#define FVWM2RC ".fvwm2rc"
 
 /* Additional version information, like date */
 #define VERSIONINFO ""
@@ -29,6 +32,14 @@
 /* Define if Xinerama library is used. */
 #undef HAVE_XINERAMA
 
+/* Define if Solaris' Xinerama calls are being used. */
+/* (Solaris 7 11/99 and later) */
+#undef HAVE_SOLARIS_XINERAMA
+
+/* Define if Solaris' X11/extensions/xinerama.h header is provided. */
+/* (Solaris 9 and later) */
+#undef HAVE_SOLARIS_XINERAMA_H
+
 /* Define if Xrender library is used. */
 #undef HAVE_XRENDER
 
@@ -63,7 +74,7 @@
 #undef USE_LIBICONV
 
 /* define if second arg of iconv use const */
-#undef ICONV_ARG_USE_CONST
+#undef ICONV_ARG_CONST
 
 #ifdef USE_LIBICONV
 /* define to use locale_charset in the place of nl_langinfog if libiconv
