@@ -71,7 +71,7 @@ static void update_nr_buttons(
 		return;
 	}
 	/* check for nr_left_buttons */
-	for (i = 0; i < NUMBER_OF_BUTTONS; i += 2)
+	for (i = 0; i < NUMBER_OF_TITLE_BUTTONS; i += 2)
 	{
 		if ((contexts & (C_L1 << i)))
 		{
@@ -82,7 +82,7 @@ static void update_nr_buttons(
 		}
 	}
 	/* check for nr_right_buttons */
-	for (i = 1; i < NUMBER_OF_BUTTONS; i += 2)
+	for (i = 1; i < NUMBER_OF_TITLE_BUTTONS; i += 2)
 	{
 		if ((contexts & (C_L1 << i)))
 		{
@@ -198,7 +198,9 @@ static int bind_get_bound_button_contexts(
 			if (b->Button_Key == 0)
 			{
 				*buttons_grabbed |=
-					((1 << NUMBER_OF_MOUSE_BUTTONS) - 1);
+					((1 <<
+					  NUMBER_OF_EXTENDED_MOUSE_BUTTONS) -
+					 1);
 			}
 			else
 			{
@@ -238,13 +240,13 @@ static int ParseBinding(
 	unsigned short *buttons_grabbed, Bool is_silent)
 {
 	char *action, context_string[20], modifier_string[20], *ptr, *token;
-	char key_string[201] = "";
+	char key_string[201] = "", buffer[80], *windowName = NULL, *p;
 	int button = 0;
 	int n1=0,n2=0,n3=0;
 	KeySym keysym = NoSymbol;
 	int context;
 	int modifier;
-	Bool is_unbind_request = False;
+	Bool is_unbind_request = False, is_pass_thru = False;
 	int rc;
 	Bool is_binding_removed = False;
 	Binding *b;
@@ -254,7 +256,36 @@ static int ParseBinding(
 	STROKE_CODE(int i);
 
 	/* tline points after the key word "Mouse" or "Key" */
-	token = PeekToken(tline, &ptr);
+	token = p = PeekToken(tline, &ptr);
+	/* check to see if a window name has been specified. */
+	if (*p == '(')
+	{
+		/* A window name has been specified for the binding. */
+		strcpy(buffer, p+1);
+		p = buffer;
+		while (*p != ')')
+		{
+			if (*p == '\0')
+			{
+				if (!is_silent)
+					fvwm_msg(ERR, "ParseBinding",
+						"Syntax error in line %s - missing ')'", tline);
+				return 0;
+			}
+			++p;
+		}
+		*p++ = '\0';
+		windowName = buffer;
+		if (*p != '\0')
+		{
+			if (!is_silent)
+				fvwm_msg(ERR, "ParseBinding",
+					"Syntax error in line %s - trailing text after specified window", tline);
+			return 0;
+		}
+		token = PeekToken(ptr, &ptr);
+	}
+
 	if (token != NULL)
 	{
 		if (BIND_IS_KEY_BINDING(type))
@@ -420,8 +451,28 @@ static int ParseBinding(
 	{
 		action++;
 	}
+
+	if (action)
+	{
+		is_pass_thru = actionIsPassThru(action);
+		if (is_pass_thru)
+		{
+			/* pass-through actions indicate that the event be
+			 * allowed to pass through to the underlying window. */
+			if (windowName == NULL)
+			{
+				/* It doesn't make sense to have a pass-through
+				 * action on global bindings. */
+				if (!is_silent)
+					fvwm_msg(ERR, "ParseBinding",
+						 "Illegal action for global "
+						 "binding: %s", tline);
+				return 0;
+			}
+		}
+	}
 	/* see if it is an unbind request */
-	if (!action || action[0] == '-')
+	if (!action || (action[0] == '-' && !is_pass_thru))
 	{
 		is_unbind_request = True;
 	}
@@ -437,7 +488,7 @@ static int ParseBinding(
 	/* BEGIN remove */
 	CollectBindingList(
 		dpy, pblist, &rmlist, type, STROKE_ARG((void *)stroke)
-		button, keysym, modifier, context);
+		button, keysym, modifier, context, windowName);
 	if (rmlist != NULL)
 	{
 		is_binding_removed = True;
@@ -492,7 +543,7 @@ static int ParseBinding(
 		if (button == 0)
 		{
 			*buttons_grabbed |=
-				((1 << NUMBER_OF_MOUSE_BUTTONS) - 1);
+				((1 << NUMBER_OF_EXTENDED_MOUSE_BUTTONS) - 1);
 		}
 		else
 		{
@@ -502,7 +553,7 @@ static int ParseBinding(
 	rc = AddBinding(
 		dpy, pblist, type, STROKE_ARG((void *)stroke)
 		button, keysym, key_string, modifier, context, (void *)action,
-		NULL);
+		NULL, windowName);
 
 	return rc;
 }
@@ -515,7 +566,7 @@ static void binding_cmd(F_CMD_ARGS, binding_t type)
 
 	count = ParseBinding(
 		dpy, &Scr.AllBindings, action, type, &Scr.nr_left_buttons,
-		&Scr.nr_right_buttons, &btg, Scr.flags.silent_functions);
+		&Scr.nr_right_buttons, &btg, Scr.flags.are_functions_silent);
 	if (btg != Scr.buttons2grab)
 	{
 		Scr.flags.do_need_window_update = 1;
