@@ -14,15 +14,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/****************************************************************************
+/*
  *
  * This is all original code by Robert Nation
  * which reads motif mwm window manager
  * hints from a window, and makes necessary adjustments for fvwm.
  *
- ****************************************************************************/
+ */
 
-/* ---------------------------- included header files ----------------------- */
+/* ---------------------------- included header files ---------------------- */
 
 #include "config.h"
 
@@ -42,7 +42,7 @@
 #include "style.h"
 #include "geometry.h"
 
-/* ---------------------------- local definitions --------------------------- */
+/* ---------------------------- local definitions -------------------------- */
 
 /* Motif window hints */
 #define MWM_HINTS_FUNCTIONS           (1L << 0)
@@ -81,42 +81,42 @@
 /* indicates if there are any OL hints */
 #define OL_ANY_HINTS                  (1L << 7)
 
-/* ---------------------------- local macros -------------------------------- */
+/* ---------------------------- local macros ------------------------------- */
 
-/* ---------------------------- imports ------------------------------------- */
+/* ---------------------------- imports ------------------------------------ */
 
 extern Atom _XA_MwmAtom;
 
-/* ---------------------------- included code files ------------------------- */
+/* ---------------------------- included code files ------------------------ */
 
-/* ---------------------------- local types --------------------------------- */
+/* ---------------------------- local types -------------------------------- */
 
 /* Motif  window hints */
 typedef struct
 {
-	int      flags;
-	int      functions;
-	int      decorations;
-	int      inputMode;
+	long flags;
+	long functions;
+	long decorations;
+	long inputMode;
 } PropMotifWmHints;
 
 typedef PropMotifWmHints PropMwmHints;
 
-/* ---------------------------- forward declarations ------------------------ */
+/* ---------------------------- forward declarations ----------------------- */
 
-/* ---------------------------- local variables ----------------------------- */
+/* ---------------------------- local variables ---------------------------- */
 
-/* ---------------------------- exported variables (globals) ---------------- */
+/* ---------------------------- exported variables (globals) --------------- */
 
-/* ---------------------------- local functions ----------------------------- */
+/* ---------------------------- local functions ---------------------------- */
 
-/* ---------------------------- interface functions ------------------------- */
+/* ---------------------------- interface functions ------------------------ */
 
-/****************************************************************************
+/*
  *
  * Reads the property MOTIF_WM_HINTS
  *
- *****************************************************************************/
+ */
 void GetMwmHints(FvwmWindow *t)
 {
 	int actual_format;
@@ -144,7 +144,7 @@ void GetMwmHints(FvwmWindow *t)
 	return;
 }
 
-/****************************************************************************
+/*
  *
  * Reads the openlook properties _OL_WIN_ATTR, _OL_DECOR_ADD, _OL_DECOR_DEL
  *
@@ -170,7 +170,7 @@ void GetMwmHints(FvwmWindow *t)
  * Window Application Programming", Eric F. Johnson and Kevin Reichard
  * (M&T Books), and the olvwm source code (available at ftp.x.org in
  * /R5contrib).
- *****************************************************************************/
+ */
 void GetOlHints(FvwmWindow *t)
 {
 	int actual_format;
@@ -308,12 +308,12 @@ void GetOlHints(FvwmWindow *t)
 }
 
 
-/****************************************************************************
+/*
  *
  * Interprets the property MOTIF_WM_HINTS, sets decoration and functions
  * accordingly
  *
- *****************************************************************************/
+ */
 void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 {
 	int decor;
@@ -337,7 +337,7 @@ void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 		handle_width = MAX_HANDLE_WIDTH;
 	}
 
-	*buttons = (1 << NUMBER_OF_BUTTONS) - 1;
+	*buttons = (1 << NUMBER_OF_TITLE_BUTTONS) - 1;
 
 	decor = MWM_DECOR_ALL;
 	t->functions = MWM_FUNC_ALL;
@@ -512,6 +512,11 @@ void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 			decor &= ~(MWM_DECOR_BORDER|MWM_DECOR_RESIZEH);
 		}
 	}
+	if (IS_EWMH_FULLSCREEN(t))
+	{
+		decor &=~(MWM_DECOR_BORDER|MWM_DECOR_RESIZEH|MWM_DECOR_TITLE);
+	}
+
 	/* Assume no decorations, and build up */
 	SET_HAS_TITLE(t, 0);
 	SET_HAS_HANDLES(t, 0);
@@ -549,7 +554,7 @@ void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 		 * window gets 1 pixel wide black border */
 		/* disable any buttons with the MWMDecorMenu flag */
 		int i;
-		for (i = 0; i < NUMBER_OF_BUTTONS; ++i)
+		for (i = 0; i < NUMBER_OF_TITLE_BUTTONS; ++i)
 		{
 			if (TB_HAS_MWM_DECOR_MENU(GetDecor(t, buttons[i])))
 			{
@@ -564,7 +569,7 @@ void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 		/* disable any buttons with the MWMDecorMinimize/MWMDecorShaded
 		 * flag */
 		int i;
-		for (i = 0; i < NUMBER_OF_BUTTONS; ++i)
+		for (i = 0; i < NUMBER_OF_TITLE_BUTTONS; ++i)
 		{
 			if (TB_HAS_MWM_DECOR_MINIMIZE(GetDecor(t, buttons[i])))
 			{
@@ -578,7 +583,7 @@ void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 		 * window has 1 pixel wide black border */
 		/* disable any buttons with the MWMDecorMaximize flag */
 		int i;
-		for (i = 0; i < NUMBER_OF_BUTTONS; ++i)
+		for (i = 0; i < NUMBER_OF_TITLE_BUTTONS; ++i)
 		{
 			if (TB_HAS_MWM_DECOR_MAXIMIZE(GetDecor(t, buttons[i])))
 			{
@@ -586,7 +591,7 @@ void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 			}
 		}
 	}
-	for (i = (1 << (NUMBER_OF_BUTTONS - 1)); i; i >>= 1)
+	for (i = (1 << (NUMBER_OF_TITLE_BUTTONS - 1)); i; i >>= 1)
 	{
 		if (t->buttons & i)
 			*buttons &= ~i;
@@ -613,7 +618,7 @@ static Bool __is_resize_allowed(FvwmWindow *t, int functions,
 				Bool is_user_request)
 {
         if (!HAS_OVERRIDE_SIZE_HINTS(t) &&
-	    t->hints.min_width == t->hints.min_width &&
+	    t->hints.min_width == t->hints.max_width &&
 	    t->hints.min_height == t->hints.max_height)
 	{
 	        return False;
