@@ -40,6 +40,7 @@
 #include "ewmh_intern.h"
 #include "decorations.h"
 #include "geometry.h"
+#include "borders.h"
 
 extern ewmh_atom ewmh_atom_wm_state[];
 
@@ -66,8 +67,9 @@ int ewmh_DesktopGeometry(EWMH_CMD_ARGS)
 	{
 		return -1;
 	}
+	sprintf(action, "DesktopSize %ld %ld", width, height);
+	execute_function_override_window(NULL, NULL, action, 0, NULL);
 
-	sprintf(action, "DesktoSize %ld %ld", width, height);
 	execute_function_override_window(NULL, NULL, action, 0, NULL);
 
 	return -1;
@@ -126,7 +128,7 @@ int ewmh_CloseWindow(EWMH_CMD_ARGS)
 int ewmh_MoveResizeWindow(EWMH_CMD_ARGS)
 {
 	XConfigureRequestEvent cre;
-	
+
 	if (ev == NULL)
 	{
 		return 0;
@@ -138,13 +140,28 @@ int ewmh_MoveResizeWindow(EWMH_CMD_ARGS)
 	cre.width = ev->xclient.data.l[3];
 	cre.height = ev->xclient.data.l[4];
 	cre.window = ev->xclient.window;
-#if 1
-	fprintf(stderr, "_NET_MOVERESIZE_WINDOW: %i,%i,%i,%i,%i (%s)\n",
-		cre.x, cre.y, cre.width, cre.height, (int)cre.value_mask,
-		(fwin)? fwin->name.name:"unmanaged");
-#endif
+
 	events_handle_configure_request(cre, fwin, True);
-	
+
+	return 0;
+}
+
+int ewmh_RestackWindow(EWMH_CMD_ARGS)
+{
+	XConfigureRequestEvent cre;
+
+	if (ev == NULL)
+	{
+		return 0;
+	}
+
+	cre.value_mask = CWSibling | CWStackMode;
+	cre.above = ev->xclient.data.l[1];
+	cre.detail = ev->xclient.data.l[2];
+	cre.window = ev->xclient.window;
+
+	events_handle_configure_request(cre, fwin, True);
+
 	return 0;
 }
 
@@ -156,7 +173,7 @@ int ewmh_WMDesktop(EWMH_CMD_ARGS)
 		unsigned long d = (unsigned long)ev->xclient.data.l[0];
 
 		/* the spec says that if d = 0xFFFFFFFF then we have to Stick
-		 * the window  however KDE use 0xFFFFFFFE :o) */
+		 * the window however KDE use 0xFFFFFFFE :o) */
 		if (d == 0xFFFFFFFE || d == 0xFFFFFFFF)
 		{
 			execute_function_override_window(
@@ -184,16 +201,20 @@ int ewmh_WMDesktop(EWMH_CMD_ARGS)
 		unsigned long *val;
 		unsigned int size = 0;
 
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_WM_DESKTOP(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (HAS_EWMH_INIT_WM_DESKTOP(fwin) !=
 		    EWMH_STATE_UNDEFINED_HINT)
 		{
 			return 0;
 		}
-
 		val = ewmh_AtomGetByName(
 			FW_W(fwin), "_NET_WM_DESKTOP",
 			EWMH_ATOM_LIST_CLIENT_WIN, &size);
-
 		if (val == NULL)
 		{
 			SET_HAS_EWMH_INIT_WM_DESKTOP(fwin, EWMH_STATE_NO_HINT);
@@ -206,25 +227,22 @@ int ewmh_WMDesktop(EWMH_CMD_ARGS)
 			HAS_EWMH_INIT_WM_DESKTOP(fwin),
 			fwin->ewmh_hint_desktop, val[0]);
 #endif
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
+		if ((val[0] == 0xFFFFFFFE || val[0] == 0xFFFFFFFF))
 		{
-			if ((val[0] == 0xFFFFFFFE || val[0] == 0xFFFFFFFF))
-			{
-				S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
-				S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
-				S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
-				S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
-				S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
-				S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
-			}
-			else if (val[0] < 256)
-			{
-				/* prevent crazy hints ?? */
-				style->flags.use_start_on_desk = 1;
-				style->flag_mask.use_start_on_desk = 1;
-				style->change_mask.use_start_on_desk = 1;
-				SSET_START_DESK(*style, val[0]);
-			}
+			S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+			S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+			S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+			S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+			S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+			S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
+		}
+		else if (val[0] < 256)
+		{
+			/* prevent crazy hints ?? */
+			style->flags.use_start_on_desk = 1;
+			style->flag_mask.use_start_on_desk = 1;
+			style->change_mask.use_start_on_desk = 1;
+			SSET_START_DESK(*style, val[0]);
 		}
 		SET_HAS_EWMH_INIT_WM_DESKTOP(fwin, EWMH_STATE_HAS_HINT);
 		fwin->ewmh_hint_desktop = val[0];
@@ -275,7 +293,6 @@ int ewmh_MoveResize(EWMH_CMD_ARGS)
 		break;
 	case _NET_WM_MOVERESIZE_MOVE_KEYBOARD:
 	case _NET_WM_MOVERESIZE_MOVE:
-		x_warp = 50; y_warp = 50; /* why not */
 		move = True;
 		break;
 	default:
@@ -297,8 +314,12 @@ int ewmh_MoveResize(EWMH_CMD_ARGS)
 		}
 	}
 
-	sprintf(cmd, "WarpToWindow %i %i",x_warp,y_warp);
-	execute_function_override_window(NULL, NULL, cmd, 0, fwin);
+	if (!move)
+	{
+		sprintf(cmd, "WarpToWindow %i %i",x_warp,y_warp);
+		execute_function_override_window(NULL, NULL, cmd, 0, fwin);
+	}
+
 	if (move)
 	{
 		execute_function_override_window(
@@ -373,7 +394,7 @@ int ewmh_WMState(EWMH_CMD_ARGS)
 					has_hint = 1;
 				}
 			}
-			maximize |= list->action(fwin, NULL, style, has_hint);
+			list->action(fwin, NULL, style, has_hint);
 			list++;
 		}
 		if (val != NULL)
@@ -417,14 +438,20 @@ int ewmh_WMStateFullScreen(EWMH_CMD_ARGS)
 	if (ev == NULL && style != NULL)
 	{
 		/* start full screen */
-		int ret = 0;
 		unsigned long has_hint = any;
+
 #if DEBUG_EWMH_INIT_STATE
 		if (has_hint)
 		{
 			fprintf(stderr,"\tFullscreen\n");
 		}
 #endif
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_FULLSCREEN_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (HAS_EWMH_INIT_FULLSCREEN_STATE(fwin) !=
 		    EWMH_STATE_UNDEFINED_HINT)
 		{
@@ -436,11 +463,7 @@ int ewmh_WMStateFullScreen(EWMH_CMD_ARGS)
 				fwin, EWMH_STATE_NO_HINT);
 			return 0;
 		}
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
-		{
-			SET_EWMH_FULLSCREEN(fwin,True);
-			ret = EWMH_MAXIMIZE_FULLSCREEN;
-		}
+		SET_EWMH_FULLSCREEN(fwin,True);
 		SET_HAS_EWMH_INIT_FULLSCREEN_STATE(fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
@@ -448,7 +471,6 @@ int ewmh_WMStateFullScreen(EWMH_CMD_ARGS)
 	if (ev != NULL)
 	{
 		/* client message */
-		char cmd[128];
 		int bool_arg = ev->xclient.data.l[0];
 		int is_full_screen;
 
@@ -456,84 +478,42 @@ int ewmh_WMStateFullScreen(EWMH_CMD_ARGS)
 		if ((bool_arg == NET_WM_STATE_TOGGLE && !is_full_screen) ||
 		    bool_arg == NET_WM_STATE_ADD)
 		{
-			fscreen_scr_arg fscr;
-			rectangle scr_g;
-			size_borders b;
-			int page_x;
-			int page_y;
-
-			/* maximize with ResizeMoveMaximize */
-			if (!is_function_allowed(
-				    F_MAXIMIZE, NULL, fwin, True, False) ||
-			    !is_function_allowed(
-				    F_MOVE, NULL, fwin, True, False) ||
-			    !is_function_allowed(
-				    F_RESIZE, NULL, fwin, True, True))
-			{
-				return 0;
-			}
-			if (IS_ICONIFIED(fwin))
-			{
-				execute_function_override_window(
-					NULL, NULL, "Iconify off", 0, fwin);
-			}
-			if (IS_SHADED(fwin))
-			{
-				int sas = fwin->shade_anim_steps;
-
-				fwin->shade_anim_steps = 0;
-				execute_function_override_window(
-					NULL, NULL, "WindowShade off", 0, fwin);
-				fwin->shade_anim_steps = sas;
-			}
-			SET_EWMH_FULLSCREEN(fwin,True);
-			apply_decor_change(fwin);
-			fscr.xypos.x =
-				fwin->frame_g.x + fwin->frame_g.width / 2;
-			fscr.xypos.y =
-				fwin->frame_g.y + fwin->frame_g.height / 2;
-			FScreenGetScrRect(
-				&fscr, FSCREEN_XYPOS, &scr_g.x, &scr_g.y,
-				&scr_g.width, &scr_g.height);
-			get_window_borders(fwin, &b);
-			get_page_offset_check_visible(&page_x, &page_y, fwin);
-			sprintf(
-				cmd, "ResizeMoveMaximize %dp %dp +%dp +%dp",
-				scr_g.width, scr_g.height,
-				scr_g.x - b.top_left.width + page_x,
-				scr_g.y - b.top_left.height + page_y);
-			if (DO_EWMH_USE_STACKING_HINTS(fwin))
-			{
-				int sl = fwin->ewmh_normal_layer;
-
-				new_layer(fwin, Scr.TopLayer);
-				if (sl == 0)
-				{
-					fwin->ewmh_normal_layer =
-						Scr.DefaultLayer;
-				}
-				else
-				{
-					fwin->ewmh_normal_layer = sl;
-				}
-			}
+			EWMH_fullscreen(fwin);
 		}
 		else
 		{
-			/* unmaximize will restore is_ewmh_fullscreen, layer
-			 * and apply_decor_change */
-			sprintf(cmd, "Maximize off");
+			if (HAS_EWMH_INIT_FULLSCREEN_STATE(fwin) !=
+			    EWMH_STATE_HAS_HINT)
+			{
+				/* unmaximize will restore is_ewmh_fullscreen,
+				 * layer and apply_decor_change */
+				execute_function_override_window(
+					NULL, NULL, "Maximize off", 0, fwin);
+			}
+			else
+			{
+				/* the application started fullscreen */
+				SET_HAS_EWMH_INIT_FULLSCREEN_STATE(
+					fwin, EWMH_STATE_NO_HINT);
+				SET_EWMH_FULLSCREEN(fwin, False);
+				if (DO_EWMH_USE_STACKING_HINTS(fwin))
+				{
+					new_layer(
+						fwin, fwin->ewmh_normal_layer);
+				}
+				apply_decor_change(fwin);
+				/* the client should resize itself */
+			}
 		}
-		execute_function_override_window(NULL, NULL, cmd, 0, fwin);
 		if ((IS_EWMH_FULLSCREEN(fwin) &&
 		     !DO_EWMH_USE_STACKING_HINTS(fwin)) ||
 		    (!IS_EWMH_FULLSCREEN(fwin) &&
 		     DO_EWMH_USE_STACKING_HINTS(fwin)))
 		{
-			/* On: if not raised by a layer cmd raise 
+			/* On: if not raised by a layer cmd raise
 			 * Off: if lowered by a layer cmd raise */
 			execute_function_override_window(
-				NULL, NULL, "Raise", 0, fwin);	
+				NULL, NULL, "Raise", 0, fwin);
 		}
 	}
 
@@ -562,10 +542,17 @@ int ewmh_WMStateHidden(EWMH_CMD_ARGS)
 	{
 		/* start iconified */
 		unsigned long has_hint = any;
+
 #if DEBUG_EWMH_INIT_STATE
 		if (has_hint)
 			fprintf(stderr,"\tHidden\n");
 #endif
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_HIDDEN_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (HAS_EWMH_INIT_HIDDEN_STATE(fwin) !=
 		    EWMH_STATE_UNDEFINED_HINT)
 		{
@@ -577,12 +564,9 @@ int ewmh_WMStateHidden(EWMH_CMD_ARGS)
 				fwin, EWMH_STATE_NO_HINT);
 			return 0;
 		}
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
-		{
-			style->flags.do_start_iconic = 1;
-			style->flag_mask.do_start_iconic = 1;
-			style->change_mask.do_start_iconic = 1;
-		}
+		style->flags.do_start_iconic = 1;
+		style->flag_mask.do_start_iconic = 1;
+		style->change_mask.do_start_iconic = 1;
 		SET_HAS_EWMH_INIT_HIDDEN_STATE(fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
@@ -619,7 +603,14 @@ int ewmh_WMStateMaxHoriz(EWMH_CMD_ARGS)
 
 	if (ev == NULL && style == NULL)
 	{
+#if 0
 		return (IS_MAXIMIZED(fwin) && !IS_EWMH_FULLSCREEN(fwin));
+#else
+		/* DV: the notion of vertical/horizontal maximization does not
+		 * make any sense in fvwm, so just claim we're never maximized
+		 */
+		return 0;
+#endif
 	}
 
 	if (ev == NULL && style != NULL)
@@ -633,6 +624,12 @@ int ewmh_WMStateMaxHoriz(EWMH_CMD_ARGS)
 				HAS_EWMH_INIT_MAXHORIZ_STATE(fwin));
 		}
 #endif
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_MAXHORIZ_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (HAS_EWMH_INIT_MAXHORIZ_STATE(fwin) !=
 		    EWMH_STATE_UNDEFINED_HINT)
 		{
@@ -642,18 +639,13 @@ int ewmh_WMStateMaxHoriz(EWMH_CMD_ARGS)
 		{
 			SET_HAS_EWMH_INIT_MAXHORIZ_STATE(
 				fwin, EWMH_STATE_NO_HINT);
-			{
-				return 0;
-			}
-		}
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
-		{
-			/* SET_MAXIMIZED(fwin, 1); */
+			return 0;
 		}
 		SET_HAS_EWMH_INIT_MAXHORIZ_STATE(fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
 
+	if (ev != NULL)
 	{
 		/* client message */
 		int bool_arg = ev->xclient.data.l[0];
@@ -667,6 +659,8 @@ int ewmh_WMStateMaxHoriz(EWMH_CMD_ARGS)
 			return EWMH_MAXIMIZE_REMOVE;
 		}
 	}
+
+	return 0;
 }
 
 int ewmh_WMStateMaxVert(EWMH_CMD_ARGS)
@@ -674,7 +668,14 @@ int ewmh_WMStateMaxVert(EWMH_CMD_ARGS)
 
 	if (ev == NULL && style == NULL)
 	{
+#if 0
 		return (IS_MAXIMIZED(fwin) && !IS_EWMH_FULLSCREEN(fwin));
+#else
+		/* DV: the notion of vertical/horizontal maximization does not
+		 * make any sense in fvwm, so just claim we're never maximized
+		 */
+		return 0;
+#endif
 	}
 
 	if (ev == NULL && style != NULL)
@@ -688,6 +689,12 @@ int ewmh_WMStateMaxVert(EWMH_CMD_ARGS)
 				HAS_EWMH_INIT_MAXVERT_STATE(fwin));
 		}
 #endif
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_MAXVERT_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (HAS_EWMH_INIT_MAXVERT_STATE(fwin) !=
 		    EWMH_STATE_UNDEFINED_HINT)
 		{
@@ -699,14 +706,11 @@ int ewmh_WMStateMaxVert(EWMH_CMD_ARGS)
 				fwin, EWMH_STATE_NO_HINT);
 			return 0;
 		}
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
-		{
-			/* SET_MAXIMIZED(fwin, 1); */
-		}
 		SET_HAS_EWMH_INIT_MAXVERT_STATE(fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
 
+	if (ev != NULL)
 	{
 		/* client message */
 		int bool_arg = ev->xclient.data.l[0];
@@ -720,6 +724,8 @@ int ewmh_WMStateMaxVert(EWMH_CMD_ARGS)
 			return EWMH_MAXIMIZE_REMOVE;
 		}
 	}
+
+	return 0;
 }
 
 int ewmh_WMStateModal(EWMH_CMD_ARGS)
@@ -751,6 +757,12 @@ int ewmh_WMStateModal(EWMH_CMD_ARGS)
 				HAS_EWMH_INIT_MODAL_STATE(fwin));
 		}
 #endif
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_MODAL_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (!has_hint &&
 		    HAS_EWMH_INIT_MODAL_STATE(fwin) != EWMH_STATE_HAS_HINT)
 		{
@@ -760,7 +772,7 @@ int ewmh_WMStateModal(EWMH_CMD_ARGS)
 		}
 
 		/* the window map or had mapped with a modal hint */
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
+		if (IS_TRANSIENT(fwin))
 		{
 			SET_EWMH_MODAL(fwin, True);
 			/* the window is a modal transient window so we grab
@@ -771,6 +783,8 @@ int ewmh_WMStateModal(EWMH_CMD_ARGS)
 				S_FOCUS_POLICY(SCM(*style)), 1);
 			FPS_GRAB_FOCUS_TRANSIENT(
 				S_FOCUS_POLICY(SCC(*style)), 1);
+			SET_HAS_EWMH_INIT_MODAL_STATE(
+				fwin, EWMH_STATE_HAS_HINT);
 		}
 		else
 		{
@@ -786,7 +800,6 @@ int ewmh_WMStateModal(EWMH_CMD_ARGS)
 					S_FOCUS_POLICY(SCC(*style)), 1);
 			}
 		}
-		SET_HAS_EWMH_INIT_MODAL_STATE(fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
 
@@ -836,6 +849,12 @@ int ewmh_WMStateShaded(EWMH_CMD_ARGS)
 				HAS_EWMH_INIT_SHADED_STATE(fwin));
 		}
 #endif
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_SHADED_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (HAS_EWMH_INIT_SHADED_STATE(fwin) !=
 		    EWMH_STATE_UNDEFINED_HINT)
 		{
@@ -847,15 +866,19 @@ int ewmh_WMStateShaded(EWMH_CMD_ARGS)
 				fwin, EWMH_STATE_NO_HINT);
 			return 0;
 		}
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
+		if (has_hint && HAS_EWMH_INIT_SHADED_STATE(fwin) ==
+		    EWMH_STATE_NO_HINT)
 		{
-			SET_SHADED(fwin, 1);
-			SET_SHADED_DIR(fwin, GET_TITLE_DIR(fwin));
+			return 0;
 		}
+
+		SET_SHADED(fwin, 1);
+		SET_SHADED_DIR(fwin, GET_TITLE_DIR(fwin));
 		SET_HAS_EWMH_INIT_SHADED_STATE(fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
 
+	if (ev != NULL)
 	{
 		/* client message */
 		int bool_arg = ev->xclient.data.l[0];
@@ -902,35 +925,37 @@ int ewmh_WMStateSkipPager(EWMH_CMD_ARGS)
 			HAS_EWMH_INIT_SKIP_PAGER_STATE(fwin),
 			DO_EWMH_IGNORE_STATE_HINTS(style));
 #endif
-		if (!has_hint && HAS_EWMH_INIT_SKIP_PAGER_STATE(fwin) !=
-		    EWMH_STATE_HAS_HINT)
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_SKIP_PAGER_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
 		{
 			SET_HAS_EWMH_INIT_SKIP_PAGER_STATE(
 				fwin, EWMH_STATE_NO_HINT);
 			return 0;
 		}
+		if (!has_hint && HAS_EWMH_INIT_SKIP_PAGER_STATE(fwin) !=
+		    EWMH_STATE_HAS_HINT)
+		{
+			return 0;
+		}
 		if (has_hint && HAS_EWMH_INIT_SKIP_PAGER_STATE(fwin) ==
 		    EWMH_STATE_NO_HINT)
 		{
 			return 0;
 		}
 
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
-		{
-			S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
-			S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
-			S_SET_DO_WINDOW_LIST_SKIP(SCC(*style), 1);
-		}
-		else if (!DO_SKIP_WINDOW_LIST(style))
-		{
-			S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 0);
-			S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
-			S_SET_DO_WINDOW_LIST_SKIP(SCC(*style), 1);
-		}
+		S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
+		S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
+		S_SET_DO_WINDOW_LIST_SKIP(SCC(*style), 1);
 		SET_HAS_EWMH_INIT_SKIP_PAGER_STATE(fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
 
+	if (ev != NULL)
 	{
 		/* I do not think we can get such client message */
 		int bool_arg = ev->xclient.data.l[0];
@@ -975,6 +1000,12 @@ int ewmh_WMStateSkipTaskBar(EWMH_CMD_ARGS)
 			HAS_EWMH_INIT_SKIP_TASKBAR_STATE(fwin),
 			DO_EWMH_IGNORE_STATE_HINTS(style));
 #endif
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_SKIP_TASKBAR_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (!has_hint && HAS_EWMH_INIT_SKIP_TASKBAR_STATE(fwin) !=
 		    EWMH_STATE_HAS_HINT)
 		{
@@ -988,23 +1019,15 @@ int ewmh_WMStateSkipTaskBar(EWMH_CMD_ARGS)
 			return 0;
 		}
 
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
-		{
-			S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
-			S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
-			S_SET_DO_WINDOW_LIST_SKIP(SCC(*style), 1);
-		}
-		else if (!DO_SKIP_WINDOW_LIST(style))
-		{
-			S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 0);
-			S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
-			S_SET_DO_WINDOW_LIST_SKIP(SCC(*style), 1);
-		}
+		S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
+		S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
+		S_SET_DO_WINDOW_LIST_SKIP(SCC(*style), 1);
 		SET_HAS_EWMH_INIT_SKIP_TASKBAR_STATE(
 			fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
 
+	if (ev != NULL)
 	{
 		/* I do not think we can get such client message */
 		int bool_arg = ev->xclient.data.l[0];
@@ -1051,6 +1074,10 @@ int ewmh_WMStateStaysOnTop(EWMH_CMD_ARGS)
 			fprintf(stderr,"\tStaysOnTop\n");
 		}
 #endif
+		if (!DO_EWMH_USE_STACKING_HINTS(style))
+		{
+			return 0;
+		}
 		if (!has_hint && fwin->ewmh_hint_layer == 0)
 		{
 			fwin->ewmh_hint_layer = -1;
@@ -1062,21 +1089,10 @@ int ewmh_WMStateStaysOnTop(EWMH_CMD_ARGS)
 		}
 
 		fwin->ewmh_hint_layer = Scr.TopLayer;
-		if (DO_EWMH_USE_STACKING_HINTS(style))
-		{
-			SSET_LAYER(*style, Scr.TopLayer);
-			style->flags.use_layer = 1;
-			style->flag_mask.use_layer = 1;
-			style->change_mask.use_layer = 1;
-		}
-		else if (!style->change_mask.use_layer)
-		{
-			fwin->ewmh_normal_layer = Scr.DefaultLayer;
-			SSET_LAYER(*style, Scr.DefaultLayer);
-			style->flags.use_layer = 1;
-			style->flag_mask.use_layer = 1;
-			style->change_mask.use_layer = 1;
-		}
+		SSET_LAYER(*style, Scr.TopLayer);
+		style->flags.use_layer = 1;
+		style->flag_mask.use_layer = 1;
+		style->change_mask.use_layer = 1;
 		return 0;
 	}
 
@@ -1127,6 +1143,10 @@ int ewmh_WMStateStaysOnBottom(EWMH_CMD_ARGS)
 		if (has_hint)
 			fprintf(stderr,"\tStaysOnBottom\n");
 #endif
+		if (!DO_EWMH_USE_STACKING_HINTS(style))
+		{
+			return 0;
+		}
 		if (!has_hint && fwin->ewmh_hint_layer == 0)
 		{
 			fwin->ewmh_hint_layer = -1;
@@ -1138,20 +1158,10 @@ int ewmh_WMStateStaysOnBottom(EWMH_CMD_ARGS)
 		}
 
 		fwin->ewmh_hint_layer = Scr.BottomLayer;
-		if (DO_EWMH_USE_STACKING_HINTS(style))
-		{
-			SSET_LAYER(*style, Scr.BottomLayer);
-			style->flags.use_layer = 1;
-			style->flag_mask.use_layer = 1;
-			style->change_mask.use_layer = 1;
-		}
-		else if (!style->change_mask.use_layer)
-		{
-			SSET_LAYER(*style, Scr.DefaultLayer);
-			style->flags.use_layer = 1;
-			style->flag_mask.use_layer = 1;
-			style->change_mask.use_layer = 1;
-		}
+		SSET_LAYER(*style, Scr.BottomLayer);
+		style->flags.use_layer = 1;
+		style->flag_mask.use_layer = 1;
+		style->change_mask.use_layer = 1;
 		return 0;
 	}
 
@@ -1204,6 +1214,12 @@ int ewmh_WMStateSticky(EWMH_CMD_ARGS)
 			fprintf(stderr,"\t Sticky\n");
 		}
 #endif
+		if (DO_EWMH_IGNORE_STATE_HINTS(style))
+		{
+			SET_HAS_EWMH_INIT_STICKY_STATE(
+				fwin, EWMH_STATE_UNDEFINED_HINT);
+			return 0;
+		}
 		if (HAS_EWMH_INIT_STICKY_STATE(fwin) !=
 		    EWMH_STATE_UNDEFINED_HINT)
 		{
@@ -1215,19 +1231,17 @@ int ewmh_WMStateSticky(EWMH_CMD_ARGS)
 				fwin, EWMH_STATE_NO_HINT);
 			return 0;
 		}
-		if (!DO_EWMH_IGNORE_STATE_HINTS(style))
-		{
-			S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
-			S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
-			S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
-			S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
-			S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
-			S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
-		}
+		S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+		S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+		S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+		S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+		S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+		S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 		SET_HAS_EWMH_INIT_STICKY_STATE(fwin, EWMH_STATE_HAS_HINT);
 		return 0;
 	}
 
+	if (ev != NULL)
 	{
 		/* client message */
 		int bool_arg = ev->xclient.data.l[0];
@@ -1380,13 +1394,14 @@ Bool EWMH_ProcessClientMessage(const exec_context_t *exc)
 		return False;
 	}
 
-	/* this one is special: we can get it on an unamaged window */
-	if (StrEquals(ewmh_a->name, "_NET_MOVERESIZE_WINDOW"))
+	/* these one are special: we can get it on an unamaged window */
+	if (StrEquals(ewmh_a->name, "_NET_MOVERESIZE_WINDOW") ||
+	    StrEquals(ewmh_a->name, "_NET_RESTACK_WINDOW"))
 	{
 		ewmh_a->action(fwin, ev, NULL, 0);
 		return True;
 	}
-	
+
 	if (fwin == NULL)
 	{
 		return False;
