@@ -1,7 +1,6 @@
-/*
- * Copyright (C) 2001  Olivier Chapuis
- *
- * This program is free software; you can redistribute it and/or modify
+/* -*-c-*- */
+/* Copyright (C) 2001  Olivier Chapuis */
+/* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -41,9 +40,9 @@
 #include "ewmh_intern.h"
 #include "externs.h"
 
-/***********************************************************************
+/*
  * set the visibale window name and icon name
- ***********************************************************************/
+ */
 void EWMH_SetVisibleName(FvwmWindow *fwin, Bool is_icon_name)
 {
 	unsigned char *val;
@@ -51,7 +50,9 @@ void EWMH_SetVisibleName(FvwmWindow *fwin, Bool is_icon_name)
 	FlocaleCharset *fc = NULL;
 
 	if (!FiconvSupport)
+	{
 		return;
+	}
 
 	/* set the ewmh visible name only if it is != wm name */
 	if (is_icon_name)
@@ -61,9 +62,9 @@ void EWMH_SetVisibleName(FvwmWindow *fwin, Bool is_icon_name)
 		    !HAS_EWMH_WM_ICON_NAME(fwin) &&
 		    !HAS_EWMH_WM_NAME(fwin))
 		{
-			ewmh_DeleteProperty(FW_W(fwin),
-					    "_NET_WM_ICON_VISIBLE_NAME",
-					    EWMH_ATOM_LIST_FVWM_WIN);
+			ewmh_DeleteProperty(
+				FW_W(fwin), "_NET_WM_ICON_VISIBLE_NAME",
+				EWMH_ATOM_LIST_FVWM_WIN);
 			return;
 		}
 		if (IS_ICON_FONT_LOADED(fwin) && fwin->icon_font != NULL)
@@ -74,12 +75,13 @@ void EWMH_SetVisibleName(FvwmWindow *fwin, Bool is_icon_name)
 	}
 	else
 	{
-		if ((fwin->name_count == 0 || !USE_INDEXED_WINDOW_NAME(fwin)) &&
+		if ((fwin->name_count == 0 ||
+		     !USE_INDEXED_WINDOW_NAME(fwin)) &&
 		    !HAS_EWMH_WM_NAME(fwin) && !HAS_EWMH_WM_ICON_NAME(fwin))
 		{
-			ewmh_DeleteProperty(FW_W(fwin),
-					    "_NET_WM_VISIBLE_NAME",
-					    EWMH_ATOM_LIST_FVWM_WIN);
+			ewmh_DeleteProperty(
+				FW_W(fwin), "_NET_WM_VISIBLE_NAME",
+				EWMH_ATOM_LIST_FVWM_WIN);
 			return;
 		}
 		if (IS_WINDOW_FONT_LOADED(fwin) && fwin->title_font != NULL)
@@ -90,32 +92,38 @@ void EWMH_SetVisibleName(FvwmWindow *fwin, Bool is_icon_name)
 	}
 
 	if (tmp_str == NULL)
+	{
 		return; /* should never happen */
+	}
 
 	val = (unsigned char *)FiconvCharsetToUtf8(
-					dpy, fc, tmp_str, strlen(tmp_str));
+		dpy, fc, tmp_str, strlen(tmp_str));
 
 	if (val == NULL)
+	{
 		return;
+	}
 
 	if (is_icon_name)
 	{
-		ewmh_ChangeProperty(FW_W(fwin), "_NET_WM_ICON_VISIBLE_NAME",
-				    EWMH_ATOM_LIST_FVWM_WIN,
-				    (unsigned char *)val, strlen(val));
+		ewmh_ChangeProperty(
+			FW_W(fwin), "_NET_WM_ICON_VISIBLE_NAME",
+			EWMH_ATOM_LIST_FVWM_WIN, (unsigned char *)val,
+			strlen(val));
 	}
 	else
 	{
-		ewmh_ChangeProperty(FW_W(fwin), "_NET_WM_VISIBLE_NAME",
-				    EWMH_ATOM_LIST_FVWM_WIN,
-				    (unsigned char *)val, strlen(val));
+		ewmh_ChangeProperty(
+			FW_W(fwin), "_NET_WM_VISIBLE_NAME",
+			EWMH_ATOM_LIST_FVWM_WIN, (unsigned char *)val,
+			strlen(val));
 	}
 	free(val);
 }
 
-/***********************************************************************
+/*
  * setup and property notify
- ***********************************************************************/
+ */
 int EWMH_WMIconName(EWMH_CMD_ARGS)
 {
 	unsigned int size = 0;
@@ -124,7 +132,9 @@ int EWMH_WMIconName(EWMH_CMD_ARGS)
 	FlocaleCharset *fc = NULL;
 
 	if (!FiconvSupport)
+	{
 		return 0;
+	}
 
 	val = ewmh_AtomGetByName(
 		FW_W(fwin), "_NET_WM_ICON_NAME",
@@ -154,7 +164,7 @@ int EWMH_WMIconName(EWMH_CMD_ARGS)
 	}
 	if (fwin->icon_name.name && strcmp(tmp_str, fwin->icon_name.name) == 0)
 	{
-		/* migo: some apps update their names every second */  
+		/* migo: some apps update their names every second */
 		free(tmp_str);
 		return 0;
 	}
@@ -221,7 +231,7 @@ int EWMH_WMName(EWMH_CMD_ARGS)
 	}
 	if (fwin->name.name && strcmp(tmp_str, fwin->name.name) == 0)
 	{
-		/* migo: some apps update their names every second */  
+		/* migo: some apps update their names every second */
 		free(tmp_str);
 		return 0;
 	}
@@ -265,9 +275,9 @@ int EWMH_WMName(EWMH_CMD_ARGS)
 }
 
 #define MAX(A,B) ((A)>(B)? (A):(B))
-/***********************************************************************
+/*
  * set the desktop name
- ***********************************************************************/
+ */
 void EWMH_SetDesktopNames(void)
 {
 	int nbr = 0;
