@@ -24,6 +24,7 @@
 #include "cursor.h"
 #include "functions.h"
 #include "misc.h"
+#include "move_resize.h"
 #include "screen.h"
 #include "geometry.h"
 #include "read.h"
@@ -116,6 +117,8 @@ static char *function_vars[] =
 	"w.width",
 	"w.x",
 	"w.y",
+	"w.desk",
+	"w.layer",
 	NULL
 };
 
@@ -183,7 +186,9 @@ enum
 	VAR_W_RESOURCE,
 	VAR_W_WIDTH,
 	VAR_W_X,
-	VAR_W_Y
+	VAR_W_Y,
+	VAR_W_DESK,
+	VAR_W_LAYER
 } extended_vars;
 
 /* ---------------------------- exported variables (globals) --------------- */
@@ -376,16 +381,20 @@ static signed int expand_vars_extended(
 		}
 		break;
 	case VAR_W_ICONFILE:
-		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
-		{
-			string = fw->icon_bitmap_file;
-		}
-		break;
 	case VAR_W_MINIICONFILE:
 		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
 		{
-			string = fw->mini_pixmap_file;
-		}
+			char *t;
+
+			t = (i == VAR_W_ICONFILE) ?
+				fw->icon_bitmap_file : fw->mini_pixmap_file;
+                        /* expand the path if possible */
+                        string = PictureFindImageFile(t, NULL, R_OK);
+                        if (!string)
+                        {
+				string = t;
+			}
+                }
 		break;
 	case VAR_W_CLASS:
 		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
@@ -573,6 +582,29 @@ static signed int expand_vars_extended(
 			}
 		}
 		break;
+	case VAR_W_DESK:
+		if (!fw || IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			return -1;
+		}
+		is_numeric = True;
+		if (is_window_sticky_across_desks(fw))
+		{
+			val = Scr.CurrentDesk;
+		}
+		else
+		{
+			val = fw->Desk;
+		}
+		break;
+	case VAR_W_LAYER:
+		if (!fw || IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			return -1;
+		}
+		is_numeric = True;
+		val = fw->layer;
+		break;
 	case VAR_SCREEN:
 		is_numeric = True;
 		val = Scr.screen;
