@@ -204,6 +204,7 @@ typedef struct
 	unsigned has_no_border : 1;
 	unsigned has_window_font : 1;
 	unsigned title_dir : 2;
+	unsigned user_states : 32;
 	/* static flags that do not change dynamically after the window has
 	 * been created */
 	struct
@@ -285,6 +286,7 @@ typedef struct
 	unsigned do_force_next_cr : 1;
 	unsigned do_force_next_pn : 1;
 	unsigned do_iconify_after_map : 1;
+	unsigned do_disable_constrain_size_fullscreen : 1;
 	/* Reuse this struct, don't free it, when destroying/recapturing
 	 * window. */
 	unsigned do_reuse_destroyed : 1;
@@ -396,9 +398,25 @@ typedef struct
 	unsigned has_ewmh_init_skip_taskbar_state : 2;
 	unsigned has_ewmh_init_sticky_state : 2;
 	unsigned has_ewmh_init_wm_desktop : 2;
-	unsigned user_states : 32;
 } window_flags;
 
+/* Window name data structure for window conditions: a list of lists
+   of names to match, the boolean operation on the matches being an
+   AND of ORs. */
+struct namelist			/* matches to names in this list are ORed */
+{
+	char *name;
+	struct namelist *next;
+};
+
+struct name_condition		/* matches to namelists in this list are
+				   ANDed, after possibly inverting each */
+{
+	Bool invert;
+	struct namelist *namelist;
+	struct name_condition *next;
+};
+
 /* Window mask for Circulate and Direction functions */
 typedef struct WindowConditionMask
 {
@@ -406,21 +424,22 @@ typedef struct WindowConditionMask
 	{
 		unsigned do_accept_focus : 1;
 		unsigned do_check_desk : 1;
-		unsigned do_check_desk_and_page : 1;
 		unsigned do_check_desk_and_global_page : 1;
-		unsigned do_check_page : 1;
+		unsigned do_check_desk_and_page : 1;
 		unsigned do_check_global_page : 1;
+		unsigned do_check_overlapped : 1;
+		unsigned do_check_page : 1;
+		unsigned do_not_check_screen : 1;
 		unsigned needs_current_desk : 1;
-		unsigned needs_current_desk_and_page : 1;
 		unsigned needs_current_desk_and_global_page : 1;
-		unsigned needs_current_page : 1;
+		unsigned needs_current_desk_and_page : 1;
 		unsigned needs_current_global_page : 1;
+		unsigned needs_current_page : 1;
 #define NEEDS_ANY   0
 #define NEEDS_TRUE  1
 #define NEEDS_FALSE 2
 		unsigned needs_focus : 2;
-		unsigned needs_name : 1;
-		unsigned needs_not_name : 1;
+		unsigned needs_overlapped : 2;
 		unsigned needs_pointer : 2;
 		unsigned needs_same_layer : 1;
 		unsigned use_circulate_hit : 1;
@@ -430,7 +449,7 @@ typedef struct WindowConditionMask
 	} my_flags;
 	window_flags flags;
 	window_flags flag_mask;
-	char *name;
+	struct name_condition *name_condition;
 	int layer;
 } WindowConditionMask;
 
@@ -467,8 +486,9 @@ typedef struct
 #define PLACE_TILECASCADE       0x5
 #define PLACE_CASCADE_B         0x6
 #define PLACE_MINOVERLAP        0x7
-#define PLACE_MASK              0x7
-	unsigned placement_mode : 3;
+#define PLACE_CENTER		0x8
+#define PLACE_MASK              0xF
+	unsigned placement_mode : 4;
 	unsigned ewmh_placement_mode : 2; /* see ewmh.h */
 #define WS_CR_MOTION_METHOD_AUTO CR_MOTION_METHOD_AUTO
 #define WS_CR_MOTION_METHOD_USE_GRAV CR_MOTION_METHOD_USE_GRAV
@@ -502,7 +522,7 @@ typedef struct
 #if 0
 	unsigned has_condition_mask : 1;
 #endif
-	unsigned is_button_disabled : NUMBER_OF_BUTTONS;
+	unsigned is_button_disabled : NUMBER_OF_TITLE_BUTTONS;
 	unsigned is_unmanaged : 1;
 #define BACKINGSTORE_DEFAULT 0
 #define BACKINGSTORE_ON      1
@@ -640,7 +660,7 @@ typedef struct FvwmWindow
 		Window client;
 		/* the title bar window and button windows */
 		Window title;
-		Window button_w[NUMBER_OF_BUTTONS];
+		Window button_w[NUMBER_OF_TITLE_BUTTONS];
 		/* sides of the border */
 		Window sides[4];
 		/* corner pieces */
@@ -654,17 +674,18 @@ typedef struct FvwmWindow
 	window_flags flags;
 	struct
 	{
-		unsigned buttons_drawn : NUMBER_OF_BUTTONS;
-		unsigned buttons_lit : NUMBER_OF_BUTTONS;
-		unsigned buttons_inverted : NUMBER_OF_BUTTONS;
-		unsigned buttons_toggled : NUMBER_OF_BUTTONS;
+		unsigned buttons_drawn : NUMBER_OF_TITLE_BUTTONS;
+		unsigned buttons_lit : NUMBER_OF_TITLE_BUTTONS;
+		unsigned buttons_inverted : NUMBER_OF_TITLE_BUTTONS;
+		unsigned buttons_toggled : NUMBER_OF_TITLE_BUTTONS;
 		unsigned parts_drawn : 12;
 		unsigned parts_lit : 12;
 		unsigned parts_inverted : 12;
 	} decor_state;
 	int nr_left_buttons;
 	int nr_right_buttons;
-#define BUTTON_INDEX(b) (((b) == 0) ? (NUMBER_OF_BUTTONS - 1) : ((b) - 1))
+#define BUTTON_INDEX(b) \
+	(((b) == 0) ? (NUMBER_OF_TITLE_BUTTONS - 1) : ((b) - 1))
 #ifdef USEDECOR
 	struct FvwmDecor *decor;
 #endif
