@@ -32,6 +32,7 @@
 #include "module_interface.h"
 #include "borders.h"
 #include "icons.h"
+#include "add_window.h"
 
 /* ---------------------------- local definitions -------------------------- */
 
@@ -96,6 +97,16 @@ void get_relative_geometry(rectangle *rel_g, rectangle *abs_g)
 	return;
 }
 
+void get_absolute_geometry(rectangle *abs_g, rectangle *rel_g)
+{
+	abs_g->x = rel_g->x + Scr.Vx;
+	abs_g->y = rel_g->y + Scr.Vy;
+	abs_g->width = rel_g->width;
+	abs_g->height = rel_g->height;
+
+	return;
+}
+
 void gravity_translate_to_northwest_geometry(
 	int gravity, FvwmWindow *t, rectangle *dest_g, rectangle *orig_g)
 {
@@ -371,7 +382,7 @@ void get_shaded_geometry(
 		if (small_g->width == 0)
 		{
 			small_g->width = 1;
-			small_g->y -= d;
+			small_g->x -= d;
 		}
 		break;
 	default:
@@ -676,6 +687,17 @@ void constrain_size(
 	int old_h = 0;
 	size_borders b;
 
+	if (DO_DISABLE_CONSTRAIN_SIZE_FULLSCREEN(fw) == 1)
+	{
+		return;
+	}
+	if (HAS_NEW_WM_NORMAL_HINTS(fw))
+	{
+		/* get the latest size hints */
+		XSync(dpy, 0);
+		GetWindowSizeHints(fw);
+		SET_HAS_NEW_WM_NORMAL_HINTS(fw, 0);
+	}
 	if (IS_MAXIMIZED(fw) && (flags & CS_UPDATE_MAX_DEFECT))
 	{
 		*widthp += fw->max_g_defect.width;
@@ -822,6 +844,10 @@ void constrain_size(
 
 	if (fw->hints.flags & PAspect)
 	{
+		double odefect;
+		double defect;
+		int ow;
+		int oh;
 
 		if (fw->hints.flags & PBaseSize)
 		{
@@ -838,7 +864,19 @@ void constrain_size(
 			maxHeight -= baseHeight;
 			minHeight -= baseHeight;
 		}
-
+		ow = dwidth;
+		oh = dheight;
+		odefect = 0;
+		if (minAspectX * dheight > minAspectY * dwidth)
+		{
+			odefect = ((double)minAspectX / (double)minAspectY -
+				   (double)dwidth / (double)dheight);
+		}
+		else if (maxAspectX * dheight < maxAspectY * dwidth)
+		{
+			odefect = ((double)dwidth / (double)dheight -
+				   (double)maxAspectX / (double)maxAspectY);
+		}
 		if ((minAspectX * dheight > minAspectY * dwidth) &&
 		    (xmotion == 0))
 		{
@@ -901,7 +939,22 @@ void constrain_size(
 				}
 			}
 		}
-
+		defect = 0;
+		if (minAspectX * dheight > minAspectY * dwidth)
+		{
+			defect = ((double)minAspectX / (double)minAspectY -
+				  (double)dwidth / (double)dheight);
+		}
+		else if (maxAspectX * dheight < maxAspectY * dwidth)
+		{
+			defect = ((double)dwidth / (double)dheight -
+				  (double)maxAspectX / (double)maxAspectY);
+		}
+		if (odefect <= defect)
+		{
+			dwidth = ow;
+			dheight = oh;
+		}
 		if (fw->hints.flags & PBaseSize)
 		{
 			dwidth += baseWidth;
@@ -1269,6 +1322,35 @@ void resize_icon_title_height(FvwmWindow *fw, int dh)
 	return;
 }
 
+void get_page_offset_rectangle(
+	int *ret_page_x, int *ret_page_y, rectangle *r)
+{
+	int xoff = Scr.Vx % Scr.MyDisplayWidth;
+	int yoff = Scr.Vy % Scr.MyDisplayHeight;
+
+	/* maximize on the page where the center of the window is */
+	*ret_page_x = truncate_to_multiple(
+		r->x + r->width / 2 + xoff, Scr.MyDisplayWidth) - xoff;
+	*ret_page_y = truncate_to_multiple(
+		r->y + r->height / 2 + yoff, Scr.MyDisplayHeight) - yoff;
+
+	return;
+}
+
+void get_page_offset(
+	int *ret_page_x, int *ret_page_y, FvwmWindow *fw)
+{
+	rectangle r;
+
+	r.x = fw->frame_g.x;
+	r.y = fw->frame_g.y;
+	r.width = fw->frame_g.width;
+	r.height = fw->frame_g.height;
+	get_page_offset_rectangle(ret_page_x, ret_page_y, &r);
+
+	return;
+}
+
 void get_page_offset_check_visible(
 	int *ret_page_x, int *ret_page_y, FvwmWindow *fw)
 {
@@ -1281,20 +1363,10 @@ void get_page_offset_check_visible(
 	}
 	else
 	{
-		int xoff = Scr.Vx % Scr.MyDisplayWidth;
-		int yoff = Scr.Vy % Scr.MyDisplayHeight;
-
-		/* maximize on the page where the center of the window is */
-		*ret_page_x = truncate_to_multiple(
-			fw->frame_g.x + fw->frame_g.width / 2 + xoff,
-			Scr.MyDisplayWidth) - xoff;
-		*ret_page_y = truncate_to_multiple(
-			fw->frame_g.y + fw->frame_g.height / 2 + yoff,
-			Scr.MyDisplayHeight) - yoff;
+		get_page_offset(ret_page_x, ret_page_y, fw);
 	}
 
 	return;
 }
 
 /* ---------------------------- builtin commands --------------------------- */
-
