@@ -873,8 +873,8 @@ static Bool __place_get_wm_pos(
 	rc = False;
 	PageLeft   = screen_g.x - pdeltax;
 	PageTop    = screen_g.y - pdeltay;
-	PageRight  = PageLeft + screen_g.width - pdeltax;
-	PageBottom = PageTop + screen_g.height - pdeltay;
+	PageRight  = PageLeft + screen_g.width;
+	PageBottom = PageTop + screen_g.height;
 	xl = -1;
 	yt = PageTop;
 	/* override if Manual placement happen */
@@ -898,6 +898,19 @@ static Bool __place_get_wm_pos(
 	reason->pos.algo = placement_mode;
 	switch (placement_mode)
 	{
+	case PLACE_CENTER:
+		attr_g->x = (screen_g.width - fw->frame_g.width) / 2;
+		attr_g->y = ((screen_g.height - fw->frame_g.height) / 2);
+		/* Don't let the upper left corner be offscreen. */
+		if (attr_g->x < PageLeft)
+		{
+			attr_g->x = PageLeft;
+		}
+		if (attr_g->y < PageTop)
+		{
+			attr_g->y = PageTop;
+		}
+		break;
 	case PLACE_TILEMANUAL:
 		flags.is_smartly_placed = SmartPlacement(
 			fw, &screen_g, fw->frame_g.width, fw->frame_g.height,
@@ -913,8 +926,8 @@ static Bool __place_get_wm_pos(
 		/* either "smart" placement fail and the second
 		 * choice is a manual placement (TileManual) or we
 		 * have a manual placement in any case (Manual) */
-		xl = -1;
-		yt = -1;
+		xl = 0;
+		yt = 0;
 		if (GrabEm(CRS_POSITION, GRAB_NORMAL))
 		{
 			int mx;
@@ -964,8 +977,7 @@ static Bool __place_get_wm_pos(
 		}
 		else
 		{
-			/* couldn't grab the pointer - better do
-			 * something */
+			/* couldn't grab the pointer - better do something */
 			XBell(dpy, 0);
 			xl = 0;
 			yt = 0;
@@ -1016,8 +1028,8 @@ static Bool __place_get_wm_pos(
 		{
 			Scr.cascade_y = 2 * fw->title_thickness;
 		}
-		attr_g->x = Scr.cascade_x + PageLeft - pdeltax;
-		attr_g->y = Scr.cascade_y + PageTop - pdeltay;
+		attr_g->x = Scr.cascade_x + PageLeft;
+		attr_g->y = Scr.cascade_y + PageTop;
 		/* try to keep the window on the screen */
 		get_window_borders(fw, &b);
 		if (attr_g->x + fw->frame_g.width >= PageRight)
@@ -1434,7 +1446,7 @@ static Bool __place_window(
 			}
 		}
 	}
-	reason->desk.desk = Scr.CurrentDesk;
+	reason->desk.desk = fw->Desk;
 	/* I think it would be good to switch to the selected desk
 	 * whenever a new window pops up, except during initialization */
 	/*  RBW - 11/02/1998  --  I dont. */
@@ -1785,6 +1797,9 @@ static void __explain_placement(FvwmWindow *fw, placement_reason_t *reason)
 
 		switch (reason->pos.algo)
 		{
+		case PLACE_CENTER:
+			a = "Center";
+			break;
 		case PLACE_TILEMANUAL:
 			a = "TileManual";
 			break;
