@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -14,7 +15,6 @@
  */
 
 /*
- * *************************************************************************
  * This module is all original code
  * by Rob Nation
  * Copyright 1993, Robert Nation
@@ -24,7 +24,6 @@
  * Changed 09/24/98 by Dan Espen:
  * - remove logic that processed and saved module configuration commands.
  * Its now in "modconf.c".
- * *************************************************************************
  */
 #include "config.h"
 
@@ -116,11 +115,11 @@ const char *get_current_read_dir(void)
 }
 
 
-/**
+/*
  * Read and execute each line from stream.
- **/
+ */
 void run_command_stream(
-	FILE *f, const exec_context_t *exc)
+	cond_rc_t *cond_rc, FILE *f, const exec_context_t *exc)
 {
 	char *tline;
 	char line[1024];
@@ -151,14 +150,7 @@ void run_command_stream(
 		{
 			tline[l - 1] = '\0';
 		}
-		if (debugging)
-		{
-			fvwm_msg(
-				DBG, "ReadSubFunc",
-				"Module switch %d, about to exec: '%s'",
-			exc->m.modnum, tline);
-		}
-		execute_function(NULL, exc, tline, 0);
+		execute_function(cond_rc, exc, tline, 0);
 		tline = fgets(line, (sizeof line) - 1, f);
 	}
 
@@ -236,7 +228,7 @@ int run_command_file(
 	{
 		return FALSE;
 	}
-	run_command_stream(f, exc);
+	run_command_stream(NULL, f, exc);
 	fclose(f);
 	pop_read_file();
 
@@ -287,30 +279,40 @@ void CMD_Read(F_CMD_ARGS)
 
 	DoingCommandLine = False;
 
-	if (debugging)
+	if (cond_rc != NULL)
 	{
-		fvwm_msg(
-			DBG, "ReadFile", "Module flag %d, about to attempt %s",
-			exc->m.modnum, action);
+		cond_rc->rc = COND_RC_OK;
 	}
-
 	if (!parse_filename("Read", action, &filename, &read_quietly))
 	{
+		if (cond_rc != NULL)
+		{
+			cond_rc->rc = COND_RC_ERROR;
+		}
 		return;
 	}
 	cursor_control(True);
-	if (!run_command_file(filename, exc) && !read_quietly)
+	if (!run_command_file(filename, exc))
 	{
-		if (filename[0] == '/')
+		if (!read_quietly)
 		{
-			fvwm_msg(ERR, "Read",
-				  "file '%s' not found",filename);
+			if (filename[0] == '/')
+			{
+				fvwm_msg(
+					ERR, "Read",
+					"file '%s' not found", filename);
+			}
+			else
+			{
+				fvwm_msg(
+					ERR, "Read",
+					"file '%s' not found in %s or "
+					FVWM_DATADIR, filename, fvwm_userdir);
+			}
 		}
-		else
+		if (cond_rc != NULL)
 		{
-			fvwm_msg(ERR, "Read",
-				 "file '%s' not found in %s or "FVWM_DATADIR,
-				 filename, fvwm_userdir);
+			cond_rc->rc = COND_RC_ERROR;
 		}
 	}
 	free(filename);
@@ -327,18 +329,26 @@ void CMD_PipeRead(F_CMD_ARGS)
 
 	DoingCommandLine = False;
 
-	if (debugging)
+	if (cond_rc != NULL)
 	{
-		fvwm_msg(DBG,"PipeRead","about to attempt '%s'", action);
+		cond_rc->rc = COND_RC_OK;
 	}
 	if (!parse_filename("PipeRead", action, &command, &read_quietly))
 	{
+		if (cond_rc != NULL)
+		{
+			cond_rc->rc = COND_RC_ERROR;
+		}
 		return;
 	}
 	cursor_control(True);
 	f = popen(command, "r");
 	if (f == NULL)
 	{
+		if (cond_rc != NULL)
+		{
+			cond_rc->rc = COND_RC_ERROR;
+		}
 		if (!read_quietly)
 		{
 			fvwm_msg(
@@ -351,7 +361,7 @@ void CMD_PipeRead(F_CMD_ARGS)
 	}
 	free(command);
 
-	run_command_stream(f, exc);
+	run_command_stream(cond_rc,f, exc);
 	pclose(f);
 	cursor_control(False);
 
