@@ -1,21 +1,6 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+/* -*-c-*- */
 
-/* File: session.h
- *
- * Description:
+/* Description:
  *       exports from session.c shall go into this file
  *
  * Created:
@@ -59,7 +44,7 @@ void RestartInSession (char *filename, Bool isNative, Bool doPreserveState);
 **  if the window should start out as shaded or maximized, respecively.
 **  The dimensions returned in x, y, w, h should be used when the
 **  window is to be maximized.
- */
+*/
 typedef struct
 {
 	int shade_dir;
@@ -70,38 +55,28 @@ typedef struct
 
 Bool MatchWinToSM(
 	FvwmWindow *ewin, mwtsm_state_args *ret_state_args,
-	initial_window_options_type *win_opts);
+	initial_window_options_t *win_opts);
 
-#ifdef SESSION
 void SetClientID(char *client_id);
 
 /*
 **  Try to open a connection to the session manager. If non-NULL,
 **  reuse the client_id.
- */
+*/
 void SessionInit(void);
 
 /*
 **  The file number of the session manager connection or -1
 **  if no session manager was found.
- */
+*/
 extern int sm_fd;
 
 /*
 **  Process messages received from the session manager. Call this
 **  from the main event loop when there is input waiting sm_fd.
- */
+*/
 void ProcessICEMsgs(void);
 
-#else
-
-#define sm_fd -1
-#define ProcessICEMsgs()
-#define SessionInit()
-#define SetClientID(client_id)
-
-#endif
-
 /*
  * Fvwm Function implementation
  */
