@@ -128,7 +128,13 @@
 #define S_TITLE_DIR(c) \
 	((c).title_dir)
 #define S_SET_TITLE_DIR(c,x) \
-	((c).title_dir = x)
+	((c).title_dir = (x))
+#define S_USER_STATES(c) \
+	((c).user_states)
+#define S_SET_USER_STATES(c,x) \
+	((c).user_states = (x))
+#define S_ADD_USER_STATES(c,x) \
+	((c).user_states = ((c).user_states | (x)))
 #define S_IS_STICKY_ACROSS_PAGES(c) \
 	((c).is_sticky_across_pages)
 #define S_SET_IS_STICKY_ACROSS_PAGES(c,x) \
