@@ -14,7 +14,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* ---------------------------- included header files ----------------------- */
+/* ---------------------------- included header files ---------------------- */
 
 #include "config.h"
 
@@ -35,38 +35,38 @@
 #include "frame.h"
 #include "focus.h"
 
-/* ---------------------------- local definitions --------------------------- */
+/* ---------------------------- local definitions -------------------------- */
 
-/* ---------------------------- local macros -------------------------------- */
+/* ---------------------------- local macros ------------------------------- */
 
-/* ---------------------------- imports ------------------------------------- */
+/* ---------------------------- imports ------------------------------------ */
 
-/* ---------------------------- included code files ------------------------- */
+/* ---------------------------- included code files ------------------------ */
 
-/* ---------------------------- local types --------------------------------- */
+/* ---------------------------- local types -------------------------------- */
 
-/* ---------------------------- forward declarations ------------------------ */
+/* ---------------------------- forward declarations ----------------------- */
 
-/* ---------------------------- local variables ----------------------------- */
+/* ---------------------------- local variables ---------------------------- */
 
-/* ---------------------------- exported variables (globals) ---------------- */
+/* ---------------------------- exported variables (globals) --------------- */
 
-/* ---------------------------- local functions ----------------------------- */
+/* ---------------------------- local functions ---------------------------- */
 
-/* ---------------------------- interface functions ------------------------- */
+/* ---------------------------- interface functions ------------------------ */
 
-/* ---------------------------- builtin commands ---------------------------- */
+/* ---------------------------- builtin commands --------------------------- */
 
-/***********************************************************************
+/*
  *
  *  WindowShade -- shades or unshades a window (veliaa@rpi.edu)
  *
  *  Args: 1 -- shade, 2 -- unshade  No Arg: toggle
  *
- ***********************************************************************/
+ */
 void CMD_WindowShade(F_CMD_ARGS)
 {
-	direction_type shade_dir;
+	direction_t shade_dir;
 	int toggle;
 	frame_move_resize_mode resize_mode;
 	rectangle start_g;
@@ -78,7 +78,7 @@ void CMD_WindowShade(F_CMD_ARGS)
 	Bool has_dir;
 	FvwmWindow * const fw = exc->w.fw;
 
-	if (IS_ICONIFIED(fw))
+	if (IS_ICONIFIED(fw) || IS_EWMH_FULLSCREEN(fw))
 	{
 		return;
 	}
