@@ -345,5 +345,23 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose);
  * Misc
  */
 
+/* return number of bytes of character at current position
+   (pointed to by str) */
+int FlocaleStringNumberOfBytes(FlocaleFont *flf, const unsigned char *str);
+
+/* given a string, font specifying its locale and a byte offset gives
+   character offset */
+int FlocaleStringByteToCharOffset(FlocaleFont *flf, const unsigned char *str,
+				  int offset);
+
+/* like above but reversed, ie. return byte offset corresponding to given 
+   charater offset */
+int FlocaleStringCharToByteOffset(FlocaleFont *flf, const unsigned char *str,
+				  int coffset);
+
+/* return length of string in characters */
+int FlocaleStringCharLength(FlocaleFont *flf, const unsigned char *str);
+
+
 #endif /* FLOCALE_H */
 
