@@ -1,17 +1,4 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+/* -*-c-*- */
 
 #ifndef Picture_Base_H
 #define Picture_Base_H
@@ -43,6 +30,15 @@ extern unsigned int Pdepth;
 extern Display *Pdpy;     /* Save area for display pointer */
 extern Bool PUseDynamicColors;
 
+typedef struct
+{
+	int color_limit;
+	int strict;
+	int allocate;
+	int not_dynamic;
+	int use_named_table;
+} PictureColorLimitOption;
+
 /* This routine called during modules initialization. Fvwm has its own code
  * in fvwm.c */
 void PictureInitCMap(Display *dpy);
@@ -50,7 +46,7 @@ void PictureInitCMap(Display *dpy);
 /* as above but force to use the default visual. If use_my_color_limit is True
  * also enable color limitation (independent than the fvwm one). */
 void PictureInitCMapRoot(
-	Display *dpy, Bool init_color_limit, char *color_limit_arg,
+	Display *dpy, Bool init_color_limit, PictureColorLimitOption *opt,
 	Bool use_my_color_limit, Bool init_dither);
 
 /* Analogue of the Xlib WhitePixel and BlackPixel functions but use the
@@ -63,10 +59,10 @@ Pixel PictureBlackPixel(void);
 void PictureSetupWhiteAndBlack(void);
 
 /* Analogue of the Xlib DefaultGC function but take care of the Pdepth:
- - If Pdepth == DefaultDepth return the DefaultGC
- - If Pdepth != DefaultDepth and first call create a static gc with the win
+   - If Pdepth == DefaultDepth return the DefaultGC
+   - If Pdepth != DefaultDepth and first call create a static gc with the win
    and return the gc
- -  If Pdepth != DefaultDepth and already called return the static gc */
+   -  If Pdepth != DefaultDepth and already called return the static gc */
 GC PictureDefaultGC(Display *dpy, Window win);
 
 /* these can be used to switch visuals before calling GetPicture */
@@ -107,6 +103,7 @@ typedef struct FvwmPictureThing
 	unsigned int count;
 	Pixel *alloc_pixels;
 	int nalloc_pixels;
+	Bool no_limit;
 } FvwmPicture;
 
 typedef struct
@@ -149,10 +146,23 @@ typedef struct
 	Pixel tint;
 	short tint_percent;
 	Pixel uniform_pixel;
-	colorset_t *colorset;;
+	colorset_t *colorset;
 } FvwmRenderAttributes;
 
+#define PICTURE_HAS_ALPHA(picture,cset) \
+    ((picture && picture->alpha != None) ||                   \
+     (cset >= 0 && Colorset[cset].icon_alpha_percent < 100))
 /* alpha limit if we cannot use the alpha channel */
 #define PICTURE_ALPHA_LIMIT 130
 
+typedef struct
+{
+	Colormap cmap;
+	int dither;
+	int no_limit;
+	Bool is_8;
+	unsigned long *pixels_table;
+	int pixels_table_size;
+} PictureImageColorAllocator;
+
 #endif /* Picture_Base_H */
