@@ -1,9 +1,8 @@
 /* -*-c-*- */
 /* Copyright (C) 1993, Robert Nation
  * Copyright (C) 1999 Carsten Haitzler and various contributors (imlib2)
- * Copyright (C) 2002  Olivier Chapuis
- *
- * This program is free software; you can redistribute it and/or modify
+ * Copyright (C) 2002  Olivier Chapuis */
+/* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -25,7 +24,7 @@
  *
  */
 
-/* ---------------------------- included header files ----------------------- */
+/* ---------------------------- included header files ---------------------- */
 
 #include "config.h"
 
@@ -45,7 +44,7 @@
 #include "FRenderInit.h"
 #include "FImage.h"
 
-/* ---------------------------- local definitions --------------------------- */
+/* ---------------------------- local definitions -------------------------- */
 #define FIMAGE_CMD_ARGS Display *dpy, Window win, char *path, \
 		  Pixmap *pixmap, Pixmap *mask, Pixmap *alpha, \
 		  int *width, int *height, int *depth, \
@@ -62,21 +61,21 @@ typedef struct PImageLoader
 #endif
 } PImageLoader;
 
-/* ---------------------------- local macros -------------------------------- */
+/* ---------------------------- local macros ------------------------------- */
 
-/* ---------------------------- imports ------------------------------------- */
+/* ---------------------------- imports ------------------------------------ */
 
-/* ---------------------------- included code files ------------------------- */
+/* ---------------------------- included code files ------------------------ */
 
-/* ---------------------------- local types --------------------------------- */
+/* ---------------------------- local types -------------------------------- */
 
-/* ---------------------------- forward declarations ------------------------ */
+/* ---------------------------- forward declarations ----------------------- */
 
 static Bool PImageLoadPng(FIMAGE_CMD_ARGS);
 static Bool PImageLoadXpm(FIMAGE_CMD_ARGS);
 static Bool PImageLoadBitmap(FIMAGE_CMD_ARGS);
 
-/* ---------------------------- local variables ----------------------------- */
+/* ---------------------------- local variables ---------------------------- */
 
 PImageLoader Loaders[] =
 {
@@ -86,16 +85,16 @@ PImageLoader Loaders[] =
 	{NULL,0}
 };
 
-/* ---------------------------- exported variables (globals) ---------------- */
+/* ---------------------------- exported variables (globals) --------------- */
 
-/* ---------------------------- local functions ----------------------------- */
+/* ---------------------------- local functions ---------------------------- */
 
 
-/* ***************************************************************************
+/*
  *
  * png loader
  *
- * ***************************************************************************/
+ */
 static
 Bool PImageLoadPng(FIMAGE_CMD_ARGS)
 {
@@ -220,18 +219,19 @@ Bool PImageLoadPng(FIMAGE_CMD_ARGS)
 	*depth = Pdepth;
 	*pixmap = XCreatePixmap(dpy, win, w, h, Pdepth);
 	*mask = XCreatePixmap(dpy, win, w, h, 1);
-	if (!(fpa.mask & FPAM_NO_ALPHA) && FRenderGetAlphaDepth())
+	if (alpha && !(fpa.mask & FPAM_NO_ALPHA) && FRenderGetAlphaDepth())
 	{
 		*alpha = XCreatePixmap(dpy, win, w, h, FRenderGetAlphaDepth());
 	}
 	if (!PImageCreatePixmapFromArgbData(
 		dpy, win, data, 0, w, h, *pixmap, *mask,
-		*alpha, &have_alpha, nalloc_pixels, alloc_pixels, no_limit, fpa)
+		(alpha)? *alpha:0,
+		&have_alpha, nalloc_pixels, alloc_pixels, no_limit, fpa)
 	    || *pixmap == None)
 	{
 		if (*pixmap != None)
 			XFreePixmap(dpy, *pixmap);
-		if (*alpha != None)
+		if (alpha && *alpha != None)
 		{
 			XFreePixmap(dpy, *alpha);
 		}
@@ -241,7 +241,7 @@ Bool PImageLoadPng(FIMAGE_CMD_ARGS)
 		free(lines);
 		return False;
 	}
-	if (!have_alpha && *alpha != None)
+	if (!have_alpha && alpha && *alpha != None)
 	{
 		XFreePixmap(dpy, *alpha);
 		*alpha = None;
@@ -251,11 +251,11 @@ Bool PImageLoadPng(FIMAGE_CMD_ARGS)
 	return True;
 }
 
-/* ***************************************************************************
+/*
  *
  * xpm loader
  *
- * ***************************************************************************/
+ */
 static
 Bool PImageLoadXpm(FIMAGE_CMD_ARGS)
 {
@@ -276,7 +276,7 @@ Bool PImageLoadXpm(FIMAGE_CMD_ARGS)
 	struct sigaction defaultHandler;
 	struct sigaction originalHandler;
 #else
-	void (*originalHandler)(int);
+	RETSIGTYPE (*originalHandler)(int);
 #endif
 
 	if (!XpmSupport)
@@ -326,7 +326,7 @@ Bool PImageLoadXpm(FIMAGE_CMD_ARGS)
 	pica = PictureOpenImageColorAllocator(
 		dpy, Pcmap, w, h,
 		fpa.mask & FPAM_NO_COLOR_LIMIT,
-		fpa.mask & FPAM_NO_ALLOC_PIXELS, 
+		fpa.mask & FPAM_NO_ALLOC_PIXELS,
 		fpa.mask & FPAM_DITHER,
 		False);
 	for(i=0; i < xpm_im.ncolors; i++)
@@ -435,11 +435,11 @@ Bool PImageLoadXpm(FIMAGE_CMD_ARGS)
 	return True;
 }
 
-/* ***************************************************************************
+/*
  *
  * bitmap loader
  *
- * ***************************************************************************/
+ */
 static
 Bool PImageLoadBitmap(FIMAGE_CMD_ARGS)
 {
@@ -455,13 +455,13 @@ Bool PImageLoadBitmap(FIMAGE_CMD_ARGS)
 	return False;
 }
 
-/* ---------------------------- interface functions ------------------------- */
+/* ---------------------------- interface functions ------------------------ */
 
-/* ***************************************************************************
+/*
  *
  * argb data to pixmaps
  *
- * ***************************************************************************/
+ */
 Bool PImageCreatePixmapFromArgbData(
 	Display *dpy, Window win, CARD32 *data, int start, int width,
 	int height, Pixmap pixmap, Pixmap mask, Pixmap alpha, int *have_alpha,
@@ -521,7 +521,7 @@ Bool PImageCreatePixmapFromArgbData(
 	pica = PictureOpenImageColorAllocator(
 		dpy, Pcmap, width, height,
 		!!(fpa.mask & FPAM_NO_COLOR_LIMIT),
-		!!(fpa.mask & FPAM_NO_ALLOC_PIXELS), 
+		!!(fpa.mask & FPAM_NO_ALLOC_PIXELS),
 		!!(fpa.mask & FPAM_DITHER),
 		True);
 
@@ -595,11 +595,11 @@ Bool PImageCreatePixmapFromArgbData(
 }
 
 
-/* ***************************************************************************
+/*
  *
  * the images loaders
  *
- * ***************************************************************************/
+ */
 
 Bool PImageLoadPixmapFromFile(
 	Display *dpy, Window win, char *path, Pixmap *pixmap, Pixmap *mask,
