@@ -1,31 +1,18 @@
 /* -*-c-*- */
-/* Copyright (C) 2002  Olivier Chapuis
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+/* Copyright (C) 2002  Olivier Chapuis */
 
 #ifndef PICTURE_IMAGE_LOADER_H
 #define PICTURE_IMAGE_LOADER_H
 
-/* ---------------------------- included header files ----------------------- */
+/* ---------------------------- included header files ---------------------- */
 
-/* ---------------------------- global macros ------------------------------- */
+#include <X11/Xmd.h>
 
-/* ---------------------------- type definitions ---------------------------- */
+/* ---------------------------- global macros ------------------------------ */
 
-/* ---------------------------- interface functions ------------------------- */
+/* ---------------------------- type definitions --------------------------- */
+
+/* ---------------------------- interface functions ------------------------ */
 
 /*
  * <pubfunc>PImageCreatePixmapFromArgbData
@@ -34,8 +21,9 @@
  * </description>
  */
 Bool PImageCreatePixmapFromArgbData(
-	Display *dpy, Window win, unsigned char *data, int start, int width,
+	Display *dpy, Window win, CARD32 *data, int start, int width,
 	int height, Pixmap pixmap, Pixmap mask, Pixmap alpha, int *have_alpha,
+	int *nalloc_pixels, Pixel **alloc_pixels, int *no_limit,
 	FvwmPictureAttributes fpa);
 /*
  * <pubfunc>PImageLoadPixmapFromFile
@@ -46,7 +34,7 @@ Bool PImageCreatePixmapFromArgbData(
 Bool PImageLoadPixmapFromFile(
 	Display *dpy, Window win, char *file, Pixmap *pixmap, Pixmap *mask,
 	Pixmap *alpha, int *width, int *height, int *depth, int *nalloc_pixels,
-	Pixel **alloc_pixels, FvwmPictureAttributes fpa);
+	Pixel **alloc_pixels, int *no_limit, FvwmPictureAttributes fpa);
 
 /*
  * <pubfunc>PImageLoadPixmapFromFile
