@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -5,12 +6,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "config.h"
@@ -18,7 +19,7 @@
 #include <stdlib.h>
 
 #include <sys/types.h>
-#include <sys/time.h>
+#include "ftime.h"
 
 #ifdef HAVE_SYS_SELECT
 #include <sys/select.h>
@@ -26,10 +27,10 @@
 
 int usleep (unsigned long usec)
 {
-    struct timeval timeout;
-    timeout.tv_usec = usec % (unsigned long) 1000000;
-    timeout.tv_sec = usec / (unsigned long) 1000000;
-    select(0, NULL, NULL, NULL, &timeout);
+	struct timeval timeout;
+	timeout.tv_usec = usec % (unsigned long) 1000000;
+	timeout.tv_sec = usec / (unsigned long) 1000000;
+	select(0, NULL, NULL, NULL, &timeout);
 
-    return 0;
+	return 0;
 }
