@@ -28,6 +28,9 @@ Pixel buttonBack(const button_info *);
 Pixel buttonHilite(button_info*);
 Pixel buttonShadow(button_info*);
 int buttonColorset(button_info *b);
+char *buttonTitle (button_info *b);
+FvwmPicture *buttonIcon (button_info *b);
+unsigned long buttonIconFlag (button_info *b);
 int buttonBackgroundButton(button_info *b, button_info **r_b);
 byte buttonSwallow(button_info*);
 byte buttonJustify(button_info*);
