@@ -40,6 +40,7 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <strings.h>	/* strncasecmp() */
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -50,12 +51,15 @@
 #include "libs/Colorset.h"
 #include "libs/fvwmlib.h"
 #include "libs/Rectangles.h"
+#include "libs/FShape.h"	/* FShapesSupported */
 #include "FvwmButtons.h"
 #include "misc.h" /* ConstrainSize() */
 #include "icons.h" /* ConfigureIconWindow() */
 #include "button.h"
 #include "draw.h"
 
+extern Pixmap shapeMask;
+
 /* ---------------- Functions that design and draw buttons ----------------- */
 
 /**
@@ -139,11 +143,6 @@ void MakeButton(button_info *b)
   /* At this point iw,ih,ix and iy should be correct. Now all we have to do is
      place title and iconwin in their proper positions */
 
-  /* For now, use the old routine in icons.h for buttons with icons */
-  if(b->flags&b_Icon && !(b->flags&b_IconAlpha))
-  {
-    ConfigureIconWindow(b, NULL);
-  }
   /* For now, hardcoded window centered, title bottom centered, below window */
   if(buttonSwallowCount(b)==3 && (b->flags & b_Swallow))
   {
@@ -182,19 +181,47 @@ void MakeButton(button_info *b)
   }
 }
 
+static int buttonBGColorset(button_info *b)
+{
+	if (b->flags & b_Hangon)
+	{
+		if ((UberButton->c->flags & b_PressColorset) &&
+			(buttonSwallow(b) & b_UseOld))
+		{
+			return UberButton->c->pressColorset;
+		}
+	}
+	else if (b == ActiveButton &&
+		UberButton->c->flags & b_ActiveColorset)
+	{
+		return UberButton->c->activeColorset;
+	}
+	else if (b == CurrentButton &&
+		UberButton->c->flags & b_PressColorset)
+	{
+		return UberButton->c->pressColorset;
+	}
+
+	if (b->flags & b_Colorset)
+	{
+		return b->colorset;
+	}
+
+	return -1;
+}
+
 /**
 *** RedrawButton()
 ***
 *** draw can be:
-*** DRAW_RELIEF: draw only the relief
 *** DRAW_CLEAN:  draw the relief, the foreground bg if any and if this
-*** the case draw the title and the icon if b_IconAlpha. This is safe
+*** the case draw the title and the icon if b_Icon. This is safe
 *** but the button background may be not repaint (if the bg of the button
 *** come from a parent button).
-*** DRAW_ALL: as above but draw the title and the icon if b_IconAlpha in
-*** any case. WARRNING: the title and the icon (b_IconAlpha) must be cleaned:
+*** DRAW_ALL: as above but draw the title and the icon if b_Icon in
+*** any case. WARRNING: the title and the icon (b_Icon) must be cleaned:
 *** if the button has a bg this is the case, but if the bg of the button
-*** come from a parent button this is not the case and xft title and alpha
+*** come from a parent button this is not the case and xft title and
 *** icons will be not draw correctly.
 *** So DRAW_ALL is ok only when you draw buttons recursively.
 *** DRAW_FORCE: draw the button and its parent fg bg. Use this only if
@@ -209,7 +236,6 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 	int i,j,k,BH,BW;
 	int f,of,x,y,px,py;
 	int ix,iy,iw,ih;
-	FlocaleFont *Ffont=buttonFont(b);
 	XGCValues gcv;
 	int rev = 0;
 	int rev_xor = 0;
@@ -222,6 +248,12 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 	Bool clean = False;
 	Bool cleaned = False;
 	Bool clear_bg = False;
+	char *title;
+
+	if (b->parent == NULL)
+	{
+		return;
+	}
 
 	cset = buttonColorset(b);
 	if (cset >= 0)
@@ -246,8 +278,8 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 
 	/* This probably isn't the place for this, but it seems to work here
 	 * and not elsewhere, so... */
-	if((b->flags & b_Swallow) && (buttonSwallowCount(b)==3) &&
-	   b->IconWin!=None)
+	if ((b->flags & b_Swallow) && (buttonSwallowCount(b) == 3) &&
+		b->IconWin != None)
 	{
 		XSetWindowBorderWidth(Dpy,b->IconWin,0);
 	}
@@ -479,58 +511,87 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 				/* module */
 			}
 		}
-		else if (b->flags & b_Colorset)
+		else if (do_draw)
 		{
-			if (do_draw)
+			int cs = buttonBGColorset(b);
+			cleaned = True;
+			XClearArea(Dpy, MyWindow, clip.x,
+				clip.y, clip.width, clip.height,
+				False);
+			if (cs >= 0)
 			{
-				cleaned = True;
-				SetClippedRectangleBackground(
-					Dpy, MyWindow, x+f, y+f, BW-2*f, BH-2*f,
-					&clip,
-					&Colorset[b->colorset],
-					Pdepth,
-					NormalGC);
+				SetRectangleBackground(Dpy, MyWindow,
+					clip.x, clip.y, clip.width,
+					clip.height, &Colorset[cs],
+					Pdepth, NormalGC);
 			}
-		}
-		else if (!(b->flags&b_IconBack) && !(b->flags&b_IconParent) &&
-			 !(b->flags&b_Swallow) && !(b->flags&b_ColorsetParent))
-		{
-			if (do_draw)
+			else if (b->flags & b_Back &&
+				!(UberButton->c->flags & b_Colorset))
 			{
-				cleaned = True;
-				XFillRectangle(
-					Dpy,MyWindow,NormalGC,
-					clip.x,clip.y,clip.width,clip.height);
+				gcv.background = b->bc;
+				XChangeGC(Dpy,NormalGC,GCBackground,
+					&gcv);
+				XFillRectangle(Dpy, MyWindow, NormalGC,
+					clip.x, clip.y, clip.width,
+					clip.height);
 			}
-		}
-		else if (clear_bg ||
-			 (pev && !buttonBackgroundButton(b,NULL) &&
-			  ((b->flags&b_Title && Ffont && Ffont->fftf.fftfont) ||
-			   (b->flags&b_Icon && b->flags&b_IconAlpha))))
-		{
-			/* some times we need to clear the real bg.
-			 * The pev expose rectangle can be bigger than the real
-			 * exposed part (as we rectangle flush and pev can
-			 * be a fake event) so we need to clear with xft font
-			 * and icons with alpha */
-			if (do_draw)
+
+			/* b_TransBack is set when using "Pixmap none" -
+			   this uses the X11 non-rectangular window shape
+			   extension. Dynamically changing the window
+			   shape (due to ActiveIcon, etc.) can cause an
+			   infinite number of Enter/Leave-Notify events,
+			   so we need to be careful. Currently, to avoid this
+			   we ensure ActiveColorset is specified if
+			   ActiveIcon is used. */
+			if (UberButton->c->flags & b_TransBack &&
+				FShapesSupported)
 			{
-				cleaned = True;
-				XClearArea(
-					Dpy, MyWindow, clip.x, clip.y,
-					clip.width, clip.height, False);
+				int w = buttonWidth(b), h = buttonHeight(b);
+				FvwmPicture *icon = buttonIcon(b);
+				XGCValues gcv;
+				GC transGC = fvwmlib_XCreateGC(Dpy, shapeMask,
+					0, &gcv);
+
+				XSetClipMask(Dpy, transGC, None);
+				XSetForeground(Dpy, transGC, 0);
+				XFillRectangle(Dpy, shapeMask, transGC,x,y,w,h);
+				XSetForeground(Dpy, transGC, 1);
+
+				if (!icon || icon->mask == None || cs >= 0)
+				{
+					XFillRectangle(Dpy, shapeMask, transGC,
+						x, y, w, h);
+				}
+				else
+				{
+					int xx, yy, ww, hh;
+					GetIconPosition(b, buttonIconFlag(b),
+						icon, &xx, &yy, &ww, &hh);
+					XCopyArea(Dpy, icon->mask, shapeMask,
+						transGC, 0, 0, icon->width,
+						icon->height, xx, yy);
+				}
+				if (buttonTitle(b))
+				{
+					DrawTitle(b, shapeMask, transGC, NULL,
+						True);
+				}
+				FShapeCombineMask(Dpy, MyWindow, FShapeBounding,
+					0, 0, shapeMask, FShapeSet);
 			}
 		}
 	}
 
 	/* ------------------------------------------------------------------ */
 
-	if(cleaned && (b->flags&b_Title))
+	title = buttonTitle(b);
+	if (cleaned && title)
 	{
 		DrawTitle(b,MyWindow,NormalGC,pev,False);
 	}
 
-	if (!(b->flags&b_Title) && (b->flags & b_Panel) &&
+	if (title == NULL && (b->flags & b_Panel) &&
 	    (b->panel_flags.panel_indicator))
 	{
 		XGCValues gcv;
@@ -612,10 +673,13 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 		}
 	} /* panel indicator */
 
-	/* redraw icons with alpha because there are drawn on the foreground */
-	if(cleaned && (b->flags&b_Icon) && (b->flags & b_IconAlpha))
+	if (cleaned)
 	{
-		DrawForegroundIcon(b, pev);
+		if (b->flags & buttonIconFlag(b))
+		{
+			/* draw icon */
+			DrawForegroundIcon(b, pev);
+		}
 	}
 
 	/* relief */
@@ -633,13 +697,15 @@ void DrawTitle(
 	FlocaleFont *Ffont=buttonFont(b);
 	int justify=buttonJustify(b);
 	int l,i,xpos;
-	char *s;
+	char *s = NULL;
 	int just=justify&b_TitleHoriz; /* Left, center, right */
 	XGCValues gcv;
 	unsigned long gcm;
 	int cset;
 	XRectangle clip;
 	Region region = None;
+	FvwmPicture *pic;
+	unsigned long iconFlag;
 
 	BH = buttonHeight(b);
 
@@ -647,10 +713,10 @@ void DrawTitle(
 
 	/* ------------------------------------------------------------------ */
 
-	if(!(b->flags&b_Title) || !Ffont)
-	{
+	s = buttonTitle(b);
+
+	if (!s || !Ffont)
 		return;
-	}
 
 	cset = buttonColorset(b);
 	gcm = 0;
@@ -673,13 +739,16 @@ void DrawTitle(
 	}
 	XChangeGC(Dpy,gc,gcm,&gcv);
 
+	pic = buttonIcon(b);
+	iconFlag = buttonIconFlag(b);
+
 	/* If a title is to be shown, truncate it until it fits */
 	if(justify&b_Horizontal && !(b->flags & b_Right))
 	{
-		if(b->flags&b_Icon)
+		if (b->flags & iconFlag)
 		{
-			ix+=b->icon->width+buttonXPad(b);
-			iw-=b->icon->width+buttonXPad(b);
+			ix += pic->width+buttonXPad(b);
+			iw -= pic->width+buttonXPad(b);
 		}
 		else if ((b->flags & b_Swallow) && buttonSwallowCount(b)==3)
 		{
@@ -688,7 +757,6 @@ void DrawTitle(
 		}
 	}
 
-	s = b->title;
 	l = strlen(s);
 	i = FlocaleTextWidth(Ffont,s,l);
 
@@ -740,7 +808,7 @@ void DrawTitle(
 		FwinString.x = xpos;
 		/* If there is more than the title, put it at the bottom */
 		/* Unless stack flag is set, put it to the right of icon */
-		if((b->flags&b_Icon ||
+		if ((b->flags & iconFlag ||
 		    ((buttonSwallowCount(b)==3) && (b->flags&b_Swallow))) &&
 		   !(justify&b_Horizontal))
 		{
