@@ -115,6 +115,7 @@ static char *my_get_font(char **s)
 /**
 *** ParseBack()
 *** Parses the options possible to Back
+*** This function appears to be obsolete & should be removed -- SS.
 **/
 static int ParseBack(char **ss)
 {
@@ -247,7 +248,8 @@ static void ParseTitle(char **ss, byte *flags, byte *mask)
 *** ParseSwallow()
 *** Parses the options possible to Swallow
 **/
-static void ParseSwallow(char **ss,unsigned int *flags,unsigned int *mask)
+static void ParseSwallow(
+	char **ss,unsigned int *flags,unsigned int *mask, button_info *b)
 {
   char *swallowopts[] =
   {
@@ -258,6 +260,7 @@ static void ParseSwallow(char **ss,unsigned int *flags,unsigned int *mask)
     "useold", "noold",
     "usetitle", "notitle",
     "fvwmmodule", "nofvwmmodule",
+    "swallownew",
     NULL
   };
   char *t,*s=*ss;
@@ -296,10 +299,12 @@ static void ParseSwallow(char **ss,unsigned int *flags,unsigned int *mask)
     case 6: /* Respawn */
       *flags|=b_Respawn;
       *mask|=b_Respawn;
+      b->newflags.do_swallow_new = 0;
       break;
     case 7: /* NoRespawn */
       *flags&=~b_Respawn;
       *mask|=b_Respawn;
+      b->newflags.do_swallow_new = 0;
       break;
     case 8: /* UseOld */
       *flags|=b_UseOld;
@@ -325,6 +330,11 @@ static void ParseSwallow(char **ss,unsigned int *flags,unsigned int *mask)
       *flags&=~b_FvwmModule;
       *mask|=b_FvwmModule;
       break;
+    case 14: /* SwallowNew */
+      *flags&=~b_Respawn;
+      *mask|=b_Respawn;
+      b->newflags.do_swallow_new = 1;
+      break;
     default:
       t=seekright(&s);
       fprintf(stderr,"%s: Illegal Swallow option \"%s\"\n",MyName,
@@ -688,7 +698,7 @@ static void ParseContainer(char **ss,button_info *b)
 	{
 	  b->c->swallow=0;
 	  b->c->swallow_mask=0;
-	  ParseSwallow(&s, &b->c->swallow, &b->c->swallow_mask);
+	  ParseSwallow(&s, &b->c->swallow, &b->c->swallow_mask, b);
 	  if(b->c->swallow_mask)
 	  {
 	    b->c->flags |= b_Swallow;
@@ -751,8 +761,7 @@ static void ParseContainer(char **ss,button_info *b)
 
     default:
       t=seekright(&s);
-      fprintf(stderr,"%s: Illegal container option \"%s\"\n",MyName,
-	      (t)?t:"");
+      fprintf(stderr,"%s: Illegal container option \"%s\"\n",MyName, (t)?t:"");
       if (t)
 	free(t);
     }
@@ -803,6 +812,10 @@ static void ParseButton(button_info **uberb,char *s)
       "colorset",
       "action",
       "id",
+      "activeicon",
+      "activetitle",
+      "pressicon",
+      "presstitle",
       NULL
     };
     s = trimleft(s);
@@ -937,13 +950,12 @@ static void ParseButton(button_info **uberb,char *s)
 	    if (b->icon_file)
 	      free(b->icon_file);
 	    b->icon_file=t;
-	    b->IconWin=None;
 	    b->flags|=b_Icon;
 	  }
 	}
 	else
 	{
-	  fprintf(stderr,"%s: Missing icon argument\n",MyName);
+	  fprintf(stderr,"%s: Missing Icon argument\n",MyName);
 	  if(t)free(t);
 	}
 	break;
@@ -1010,7 +1022,7 @@ static void ParseButton(button_info **uberb,char *s)
 	if(*s=='(' && s++)
 	{
 	  if (is_swallow)
-	    ParseSwallow(&s, &b->swallow,&b->swallow_mask);
+	    ParseSwallow(&s, &b->swallow,&b->swallow_mask, b);
 	  else
 	    ParsePanel(&s, &b->swallow, &b->swallow_mask, &b->slide_direction,
 		       &b->slide_steps, &b->slide_delay_ms, &b->panel_flags,
@@ -1251,6 +1263,123 @@ static void ParseButton(button_info **uberb,char *s)
 	}
 	break;
 
+	/* ---------------------------- ActiveIcon ------------------------- */
+	case 21: /* ActiveIcon */
+		t = seekright(&s);
+		if (t && *t && (t[0] != '-' || t[1] != 0))
+		{
+			if (b->flags & b_Swallow)
+			{
+				fprintf(stderr,"%s: a button can not have a "
+					"ActiveIcon and a swallowed window at "
+					"the same time. Ignoring ActiveIcon.",
+					MyName);
+			}
+			else
+			{
+				if (b->active_icon_file)
+					free(b->active_icon_file);
+				b->active_icon_file = t;
+				b->flags |= b_ActiveIcon;
+			}
+		}
+		else
+		{
+			fprintf(stderr,"%s: Missing ActiveIcon argument\n",
+				MyName);
+			if (t)
+				free(t);
+		}
+		break;
+
+	/* ------------------------- ActiveTitle ------------------------- */
+	case 22: /* ActiveTitle */
+		s = trimleft(s);
+		if (*s=='(')
+		{
+			fprintf(stderr,"%s: justification not allowed for "
+				"ActiveTitle.\n", MyName);
+		}
+		t = seekright(&s);
+		if(t && *t && (t[0] != '-' || t[1] != 0))
+		{
+			if (b->activeTitle)
+				free(b->activeTitle);
+			b->activeTitle = t;
+#ifdef DEBUG_PARSER
+			fprintf(stderr,"PARSE: ActiveTitle \"%s\"\n",
+				b->activeTitle);
+#endif
+			b->flags |= b_ActiveTitle;
+		}
+		else
+		{
+			fprintf(stderr,"%s: Missing ActiveTitle argument\n",
+					MyName);
+			if (t)
+				free(t);
+		}
+		break;
+
+	/* ------------------------- PressIcon ------------------------- */
+	case 23: /* PressIcon */
+		t = seekright(&s);
+		if (t && *t && (t[0] != '-' || t[1] != 0))
+		{
+			if (b->flags & b_Swallow)
+			{
+				fprintf(stderr,"%s: a button can not have a "
+					"PressIcon and a swallowed window at "
+					"the same time. Ignoring PressIcon.",
+					MyName);
+			}
+			else
+			{
+				if (b->press_icon_file)
+					free(b->press_icon_file);
+				b->press_icon_file = t;
+				b->flags |= b_PressIcon;
+			}
+		}
+		else
+		{
+			fprintf(stderr,"%s: Missing PressIcon argument\n",
+				MyName);
+			if (t)
+				free(t);
+		}
+		break;
+
+	/* ------------------------- PressTitle ------------------------- */
+	case 24: /* PressTitle */
+		s = trimleft(s);
+		if (*s=='(')
+		{
+			fprintf(stderr,"%s: justification not allowed for "
+				"PressTitle.\n", MyName);
+		}
+		t = seekright(&s);
+		if (t && *t && (t[0] != '-' || t[1] != 0))
+		{
+			if (b->pressTitle)
+				free(b->pressTitle);
+			b->pressTitle = t;
+#ifdef DEBUG_PARSER
+			fprintf(stderr,"PARSE: PressTitle \"%s\"\n",
+				b->pressTitle);
+#endif
+			b->flags |= b_PressTitle;
+		}
+		else
+		{
+			fprintf(stderr,"%s: Missing PressTitle argument\n",
+				MyName);
+			if (t)
+				free(t);
+		}
+		break;
+
+	/* ------------------------- ------------------------- */
       default:
 	t=seekright(&s);
 	fprintf(stderr,"%s: Illegal button option \"%s\"\n",MyName,
@@ -1292,7 +1421,6 @@ static void ParseButton(button_info **uberb,char *s)
        ((b->icon_file)[0]!='-'||(b->icon_file)[1]!=0))
     {
       b->flags|=b_Icon;
-      b->IconWin=None;
     }
     else
       if(b->icon_file)free(b->icon_file);
@@ -1370,6 +1498,8 @@ static void ParseConfigLine(button_info **ubb,char *s)
     "pixmap",
     "boxsize",
     "colorset",
+    "activecolorset",
+    "presscolorset",
     NULL
   };
   int i,j,k;
@@ -1468,6 +1598,34 @@ static void ParseConfigLine(button_info **ubb,char *s)
       ub->c->flags &= ~b_Colorset;
     }
     break;
+  case 13: /* ActiveColorset */
+    i = sscanf(s, "%d", &j);
+    if (i > 0)
+    {
+      ub->c->activeColorset = j;
+      ub->c->flags |= b_ActiveColorset;
+      AllocColorset(j);
+    }
+    else
+    {
+      ub->c->flags &= ~b_ActiveColorset;
+    }
+    break;
+
+  case 14: /* PressColorset */
+    i = sscanf(s, "%d", &j);
+    if (i > 0)
+    {
+      ub->c->pressColorset = j;
+      ub->c->flags |= b_PressColorset;
+      AllocColorset(j);
+    }
+    else
+    {
+      ub->c->flags &= ~b_PressColorset;
+    }
+    break;
+
   default:
     s = trimleft(s);
     ParseButton(ubb,s);
