@@ -34,7 +34,7 @@
 #define MAXHOSTNAME 32
 
 static int  Fdr, Fdw;  /* file discriptor for fifo */
-static FILE *Frun;     /* File contains pid */
+static int  Fdrun;     /* file discriptor for run file */
 static struct stat stat_buf;
 static char *Fr_name;
 static fd_set fdset;
@@ -56,7 +56,6 @@ void err_quit( const char *msg );
 void sendit( char *cmd );
 void receive( void );
 static RETSIGTYPE sig_ttin(int);
-/* void sig_pipe( int ); */
 static RETSIGTYPE sig_quit(int);
 void usage(void);
 int  read_f(int fd, char *p, int len);
@@ -125,16 +124,19 @@ int main ( int argc, char *argv[])
     sigaction(SIGHUP, &sigact, NULL);
     sigaction(SIGQUIT, &sigact, NULL);
     sigaction(SIGTERM, &sigact, NULL);
+    sigaction(SIGPIPE, &sigact, NULL);
   }
 #else
 #ifdef USE_BSD_SIGNALS
-  fvwmSetSignalMask( sigmask(SIGINT) | sigmask(SIGHUP) |
-		     sigmask(SIGQUIT) | sigmask(SIGTERM) );
+  fvwmSetSignalMask(
+	  sigmask(SIGINT) | sigmask(SIGHUP) | sigmask(SIGQUIT) |
+	  sigmask(SIGTERM) | sigmask(SIGPIPE));
 #endif
   signal(SIGINT, sig_quit);
   signal(SIGHUP, sig_quit);
   signal(SIGQUIT, sig_quit);
   signal(SIGTERM, sig_quit);
+  signal(SIGPIPE, sig_quit);
   signal(SIGTTIN, sig_ttin);
   signal(SIGTTOU, sig_ttin);
 #ifdef HAVE_SIGINTERRUPT
@@ -142,6 +144,7 @@ int main ( int argc, char *argv[])
   siginterrupt(SIGHUP, 1);
   siginterrupt(SIGQUIT, 1);
   siginterrupt(SIGTERM, 1);
+  siginterrupt(SIGPIPE, 1);
   siginterrupt(SIGTTIN, 0);
   siginterrupt(SIGTTOU, 0);
 #endif
@@ -267,22 +270,30 @@ int main ( int argc, char *argv[])
   strcpy(Fr_name,f_stem);
   strcat(Fr_name, "R");
 
-  if ((Frun = fopen (Fr_name,"r" )) !=NULL)
+  Fdrun = open(Fr_name, O_WRONLY | O_CREAT | O_EXCL, 0600);
+  if (Fdrun < 0)
   {
-    if (fgets (cmd, 20, Frun) != NULL)
+    FILE *f;
+
+    if ((f = fopen (Fr_name,"r" )) != NULL)
     {
+      *cmd = 0;
+      fgets(cmd, 20, f);
+      fclose(f);
       fprintf (stderr, "\nFvwmCommand lock file %sR is detected. "
 	       "This may indicate another FvwmCommand is running. "
 	       "It appears to be running under process ID:\n%s\n",
-	       f_stem, cmd );
+	       f_stem, (*cmd) ? cmd : "(unknown)" );
       fprintf (stderr, "You may either kill the process or run FvwmCommand "
 	       "with another FIFO set using option -S and -f. "
 	       "If the process doesn't exist, simply remove file:\n%sR\n\n",
 	       f_stem);
       exit(1);
     }
-    fclose (Frun);
-    unlink (Fr_name);
+    else
+    {
+      err_quit ("writing lock file");
+    }
   }
 
   if( Opt_Serv )
@@ -291,14 +302,12 @@ int main ( int argc, char *argv[])
     system (cmd);
   }
 
-  if ((Frun = fopen (Fr_name,"w" )) != NULL)
   {
-    fprintf (Frun, "%d\n", (int) getpid());
-    fclose (Frun);
-  }
-  else
-  {
-      err_quit ("writing lock file");
+    char buf[64];
+
+    sprintf(buf, "%d\n", (int)getpid());
+    write(Fdrun, buf, strlen(buf));
+    close(Fdrun);
   }
 
   Fdr = Fdw = -1;
@@ -433,6 +442,7 @@ sig_ttin(int dummy)
 
   Bg = 1;
   signal(SIGTTIN, SIG_IGN);
+  signal(SIGTTOU, SIG_IGN);
   SIGNAL_RETURN;
 }
 
