@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /*
  * Fvwm command input interface.
  *
@@ -23,6 +24,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "config.h"
+
 #include "FvwmCommand.h"
 #include "libs/fvwmlib.h"
 #include "libs/fvwmsignal.h"
@@ -143,6 +146,7 @@ static RETSIGTYPE
 sig_handler(int signo)
 {
   fvwmSetTerminate(signo);
+  SIGNAL_RETURN;
 }
 
 /*
