@@ -23,6 +23,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+/* FIXME: The signal handling of this module is largely broken */
+
 #include "config.h"
 
 #include "FvwmConsole.h"
@@ -30,15 +32,41 @@
 char *MyName;
 
 int Fd[2];  /* pipe to fvwm */
-int  Ns;             /* socket handles */
+int  Ns = -1; /* socket handles */
 char Name[80]; /* name of this program in executable format */
 char *S_name;  /* socket name */
 
-void server( void );
-RETSIGTYPE DeadPipe( int );
-void CloseSocket();
-void ErrMsg( char *msg );
-void SigHandler( int );
+void server(void);
+RETSIGTYPE DeadPipe(int);
+void CloseSocket(void);
+void ErrMsg(char *msg);
+void SigHandler(int);
+
+void clean_up(void)
+{
+	if (Ns != -1)
+	{
+		close(Ns);
+		Ns = -1;
+		}
+	if (S_name != NULL)
+	{
+		unlink(S_name);
+		S_name = NULL;
+	}
+
+	return;
+}
+
+RETSIGTYPE ReapChildren(int sig)
+{
+	fvwmReapChildren(sig);
+
+	clean_up();
+	exit(0);
+
+	SIGNAL_RETURN;
+}
 
 int main(int argc, char *argv[])
 {
@@ -62,38 +90,38 @@ int main(int argc, char *argv[])
   if (s != NULL)
     tmp = s + 1;
 
-  strcpy( Name, tmp );
+  strcpy(Name, tmp);
 
   MyName = safemalloc(strlen(tmp)+2);
   strcpy(MyName,"*");
   strcat(MyName, tmp);
 
   /* construct client's name */
-  strcpy( client, argv[0] );
-  strcat( client, "C" );
+  strcpy(client, argv[0]);
+  strcat(client, "C");
 
-  if(argc < FARGS)    {
+  if (argc < FARGS)    {
 	fprintf(stderr,"%s version %s should only be executed by fvwm!\n",
 		MyName, VERSION);
 	exit(1);
   }
 
-  if( ( eargv =(char **)safemalloc((argc+12)*sizeof(char *)) ) == NULL ) {
-	ErrMsg( "allocation" );
+  if ((eargv =(char **)safemalloc((argc+12)*sizeof(char *))) == NULL) {
+	ErrMsg("allocation");
   }
 
   /* copy arguments */
   eargv[0] = XTERM;
   j = 1;
-  for ( k=0 ; xterm_pre[k] != NULL ; j++, k++ ) {
+  for (k=0 ; xterm_pre[k] != NULL ; j++, k++) {
 	eargv[j] = xterm_pre[k];
   }
 
-  for ( i=FARGS ; i<argc; i++ ) {
-	if( !strcmp ( argv[i], "-e" ) ) {
+  for (i=FARGS ; i<argc; i++) {
+	if (!strcmp (argv[i], "-e")) {
 	  i++;
 	  break;
-	} else if( !strcmp ( argv[i], "-terminal" ) ) {
+	} else if (!strcmp (argv[i], "-terminal")) {
 	  i++;
 	  if (i < argc)
 	    /* use alternative terminal emulator */
@@ -103,17 +131,18 @@ int main(int argc, char *argv[])
 	}
   }
 
-  for ( k=0 ; xterm_post[k] != NULL ; j++, k++ ) {
+  for (k=0 ; xterm_post[k] != NULL ; j++, k++) {
 	eargv[j] = xterm_post[k];
   }
 
   /* copy rest of -e args */
-  for(  ; i<argc; i++, j++ ) {
+  for( ; i<argc; i++, j++) {
 	  eargv[j-1] = argv[i];
   }
 
   eargv[j] = NULL;
 
+  signal (SIGCHLD, ReapChildren);
   /* Dead pipes mean fvwm died */
   signal (SIGPIPE, DeadPipe);
   signal (SIGINT, SigHandler);
@@ -124,10 +153,10 @@ int main(int argc, char *argv[])
 
   /* launch xterm with client */
   clpid = fork();
-  if( clpid < 0) {
+  if (clpid < 0) {
 	ErrMsg("client forking");
-  }else if(clpid  == 0 ) {
-	execvp( *eargv, eargv );
+  }else if (clpid  == 0) {
+	execvp(*eargv, eargv);
 	ErrMsg("exec");
   }
 
@@ -141,35 +170,24 @@ int main(int argc, char *argv[])
 /*
  *      signal handler
  */
-RETSIGTYPE DeadPipe( int dummy )
+RETSIGTYPE DeadPipe(int dummy)
 {
-  CloseSocket();
-  exit(0);
-  SIGNAL_RETURN;
+	clean_up();
+	exit(0);
+	SIGNAL_RETURN;
 }
 
 RETSIGTYPE SigHandler(int dummy)
 {
-  CloseSocket();
-  exit(1);
-  SIGNAL_RETURN;
-}
-
-/*
- * close sockets and spawned process
- */
-void CloseSocket()
-{
-  send(Ns, C_CLOSE, strlen(C_CLOSE), 0);
-  close(Ns);     /* remove the socket */
-  unlink( S_name );
-
+	clean_up();
+	exit(0);
+	SIGNAL_RETURN;
 }
 
 /*
  * setup server and communicate with fvwm and the client
  */
-void server ( void )
+void server (void)
 {
   struct sockaddr_un sas, csas;
   int  len;
@@ -183,41 +201,42 @@ void server ( void )
   int msglen;
 
   /* make a socket  */
-  if( (s = socket(AF_UNIX, SOCK_STREAM, 0 )) < 0  ) {
-	ErrMsg( "socket");
+  if ((s = socket(AF_UNIX, SOCK_STREAM, 0)) < 0 ) {
+	ErrMsg("socket");
 	exit(1);
   }
 
   /* name the socket */
   home = getenv("FVWM_USERDIR");
-  S_name = safemalloc(strlen(home) + sizeof(S_NAME) + 1);
+  S_name = safemalloc(strlen(home) + sizeof(S_NAME) + 11);
   strcpy(S_name, home);
   strcat(S_name, S_NAME);
 
   sas.sun_family = AF_UNIX;
-  strcpy( sas.sun_path, S_name );
+  strcpy(sas.sun_path, S_name);
 
   /* bind the above name to the socket */
   /* first, erase the old socket */
-  unlink( S_name );
-  len = sizeof(sas) - sizeof( sas.sun_path) + strlen( sas.sun_path );
+  unlink(S_name);
+  len = sizeof(sas) - sizeof(sas.sun_path) + strlen(sas.sun_path);
 
-  if( bind(s, (struct sockaddr *)&sas,len) < 0 ) {
-	ErrMsg( "bind" );
+  umask(0077);
+  if (bind(s, (struct sockaddr *)&sas,len) < 0) {
+	ErrMsg("bind");
 	exit(1);
   }
 
   /* listen to the socket */
   /* set backlog to 5 */
-  if ( listen(s,5) < 0 ) {
-    ErrMsg( "listen" );
+  if (listen(s,5) < 0) {
+    ErrMsg("listen");
 	exit(1);
   }
 
   /* accept connections */
   clen = sizeof(csas);
-  if(( Ns = accept(s, (struct sockaddr *)&csas, &clen)) < 0 ) {
-	ErrMsg( "accept");
+  if ((Ns = accept(s, (struct sockaddr *)&csas, &clen)) < 0) {
+	ErrMsg("accept");
 	exit(1);
   }
 
@@ -225,19 +244,19 @@ void server ( void )
   tline = NULL;
   send(Ns, C_BEG, strlen(C_BEG), 0);
   GetConfigLine(Fd,&tline);
-  while(tline != NULL) {
-	if(strlen(tline)>1) {
+  while (tline != NULL) {
+	if (strlen(tline)>1) {
 	  send(Ns, tline, strlen(tline),0);
 	  send(Ns, "\n", 1, 0);
 	}
 	GetConfigLine(Fd,&tline);
   }
   send(Ns, C_END, strlen(C_END), 0);
-  strcpy( ver, MyName);
-  strcat( ver, " version " );
-  strcat( ver, VERSION VERSIONINFO);
-  strcat( ver, "\n" );
-  send(Ns, ver, strlen(ver), 0 );
+  strcpy(ver, MyName);
+  strcat(ver, " version ");
+  strcat(ver, VERSION VERSIONINFO);
+  strcat(ver, "\n");
+  send(Ns, ver, strlen(ver), 0);
 
   while (1){
       FD_ZERO(&fdset);
@@ -248,27 +267,26 @@ void server ( void )
 
       if (FD_ISSET(Fd[1], &fdset)){
 	  FvwmPacket* packet = ReadFvwmPacket(Fd[1]);
-	  if ( packet == NULL ) {
-	      CloseSocket();
-	      exit(0);
+	  if (packet == NULL) {
+		  clean_up();
+		  exit(0);
 	  } else {
 	      if (packet->type == M_PASS) {
 		  msglen = strlen((char *)&(packet->body[3]));
-		  if ( msglen > MAX_MESSAGE_SIZE-2 ) {
+		  if (msglen > MAX_MESSAGE_SIZE-2) {
 		      msglen = MAX_MESSAGE_SIZE-2;
 		  }
-		  send( Ns, (char *)&(packet->body[3]), msglen, 0 );
+		  send(Ns, (char *)&(packet->body[3]), msglen, 0);
 	      }
 	  }
       }
 
       if (FD_ISSET(Ns, &fdset)){
 	  int len;
-	  if( recv( Ns, buf, MAX_COMMAND_SIZE,0 ) == 0 ) {
-	    /* client is terminated */
-	    close(Ns);
-	    unlink(S_name);
-	    exit(0);
+	  if (recv(Ns, buf, MAX_COMMAND_SIZE,0) == 0) {
+		  /* client is terminated */
+		  clean_up();
+		  exit(0);
 	  }
 
 	  /* process the own unique commands */
@@ -285,9 +303,11 @@ void server ( void )
 /*
  * print error message on stderr and exit
  */
-void ErrMsg( char *msg )
+void ErrMsg(char *msg)
 {
-  fprintf( stderr, "%s server error in %s, errno %d\n", Name, msg, errno );
-  CloseSocket();
-  exit(1);
+	fprintf(
+		stderr, "%s server error in %s, errno %d: %s\n", Name, msg,
+		errno, strerror(errno));
+	clean_up();
+	exit(1);
 }
