@@ -1,18 +1,4 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
+/* -*-c-*- */
 #ifndef FVWMFORM_H
 #define FVWMFORM_H
 
@@ -261,7 +247,7 @@ extern int Channel[2];
 /* From FvwmAnimate end */
 
 /* prototypes */
-void ReadXServer();                      /* ReadXServer.c */
+void ReadXServer(void);                  /* ReadXServer.c */
 void RedrawText(Item *item);             /* FvwmForm.c */
 void RedrawTimeout(Item *item);          /* FvwmForm.c */
 void RedrawItem (
@@ -273,6 +259,6 @@ int FontWidth (XFontStruct *xfs);        /* FvwmForm.c */
 void RedrawFrame (XEvent *pev);          /* FvwmForm.c */
 char * ParseCommand (int, char *, char, int *, char **s); /* ParseCommand.c */
 
-void DeadPipe(int nonsense);            /* FvwmForm.c */
+RETSIGTYPE DeadPipe(int nonsense);            /* FvwmForm.c */
 
 #endif
