@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,6 +14,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "config.h"
+
 #include <unistd.h>
 #include <stdlib.h>
 #include <signal.h>
@@ -113,6 +116,7 @@ static RETSIGTYPE
 TerminateHandler(int sig)
 {
 	fvwmSetTerminate(sig);
+	SIGNAL_RETURN;
 }
 
 
@@ -128,6 +132,7 @@ DeadPipe(int nothing)
 {
 	(void)nothing;
 	ShutMeDown(0);
+	SIGNAL_RETURN;
 }
 
 static void
