@@ -1,3 +1,4 @@
+/* -*-c-*- */
 
 /* This module, and the entire NoClutter program, and the concept for
  * interfacing this module to the Window Manager, are all original work
@@ -117,12 +118,12 @@ static char ewmh_init_state[512];
 static int minimal_layer = default_layer;
 static int my_layer = default_layer;
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      main - start of module
  *
- ***********************************************************************/
+ */
 int main(int argc, char **argv)
 {
 	char *temp, *s;
@@ -322,11 +323,11 @@ int main(int argc, char **argv)
 	return 0;
 }
 
-/**************************************************************************
+/*
  *
  * Read the entire window list from fvwm
  *
- *************************************************************************/
+ */
 void Loop(int *fd)
 {
 	while (1)
@@ -344,11 +345,11 @@ void Loop(int *fd)
 }
 
 
-/**************************************************************************
+/*
  *
  * Process window list messages
  *
- *************************************************************************/
+ */
 void process_message(unsigned long type,unsigned long *body)
 {
 	switch(type)
@@ -378,23 +379,24 @@ void process_message(unsigned long type,unsigned long *body)
 	}
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      SIGPIPE handler - SIGPIPE means fvwm is dying
  *
- ***********************************************************************/
+ */
 static RETSIGTYPE
 TerminateHandler(int sig)
 {
 	fvwmSetTerminate(sig);
+	SIGNAL_RETURN;
 }
 
-/***********************************************************************
+/*
  *
  * Got window configuration info - if its our window, save data
  *
- ***********************************************************************/
+ */
 void list_configure(unsigned long *body)
 {
 	struct ConfigWinPacket  *cfgpacket = (void *) body;
@@ -434,11 +436,11 @@ void list_configure(unsigned long *body)
 	}
 }
 
-/*************************************************************************
+/*
  *
  * Capture  Window name info
  *
- ************************************************************************/
+ */
 void list_window_name(unsigned long *body)
 {
 	if((app_win == (Window)body[1])||(app_win == (Window)body[0]))
@@ -447,11 +449,11 @@ void list_window_name(unsigned long *body)
 	}
 }
 
-/*************************************************************************
+/*
  *
  * Capture  Window Icon name info
  *
- ************************************************************************/
+ */
 void list_icon_name(unsigned long *body)
 {
 	if((app_win == (Window)body[1])||(app_win == (Window)body[0]))
@@ -461,11 +463,11 @@ void list_icon_name(unsigned long *body)
 }
 
 
-/*************************************************************************
+/*
  *
  * Capture  Window class name info
  *
- ************************************************************************/
+ */
 void list_class(unsigned long *body)
 {
 	if((app_win == (Window)body[1])||(app_win == (Window)body[0]))
@@ -475,11 +477,11 @@ void list_class(unsigned long *body)
 }
 
 
-/*************************************************************************
+/*
  *
  * Capture  Window resource info
  *
- ************************************************************************/
+ */
 void list_res_name(unsigned long *body)
 {
 	if((app_win == (Window)body[1])||(app_win == (Window)body[0]))
@@ -568,11 +570,11 @@ void list_config_info(unsigned long *body)
 		free(token);
 }
 
-/*************************************************************************
+/*
  *
  * Process X Events
  *
- ************************************************************************/
+ */
 int ProcessXEvent(int x, int y)
 {
 	XEvent Event,event;
@@ -690,7 +692,9 @@ int ProcessXEvent(int x, int y)
 			    (x != Event.xconfigure.x ||
 			     y != Event.xconfigure.y))
 			{
+				static Bool is_initial_cn = True;
 				Bool do_eat_expose = False;
+
 				x = Event.xconfigure.x;
 				y = Event.xconfigure.y;
 				/* flush any expose events */
@@ -712,7 +716,8 @@ int ProcessXEvent(int x, int y)
 				{
 					do_eat_expose = True;
 				}
-				if (do_eat_expose == True)
+				if (do_eat_expose == True &&
+				    is_initial_cn == False)
 				{
 					while (FCheckTypedEvent(
 						dpy, Expose, &Event))
@@ -720,6 +725,7 @@ int ProcessXEvent(int x, int y)
 						/* nothing */
 					}
 				}
+				is_initial_cn = False;
 			}
 			break;
 		}
@@ -729,11 +735,11 @@ int ProcessXEvent(int x, int y)
 	return 0;
 }
 
-/*************************************************************************
+/*
  *
  * End of window list, open an x window and display data in it
  *
- ************************************************************************/
+ */
 void list_end(void)
 {
 	XSizeHints mysizehints;
@@ -923,11 +929,11 @@ void list_end(void)
 	}
 }
 
-/************************************************************************
+/*
  *
  * Draw the items
  *
- ***********************************************************************/
+ */
 void DrawItems(Drawable d, int x, int y, int w, int h)
 {
 	int fontheight,i=0;
@@ -1031,9 +1037,9 @@ void PixmapDrawWindow(int w, int h)
 	}
 }
 
-/**************************************************************************
+/*
  *  Change the window name displayed in the title bar.
- **************************************************************************/
+ */
 void change_window_name(char *str)
 {
 	XTextProperty name;
@@ -1066,11 +1072,11 @@ void DestroyList(void)
 	itemlistRoot = NULL;
 }
 
-/**************************************************************************
+/*
 *
 * Add s1(string at first column) and s2(string at second column) to itemlist
 *
- *************************************************************************/
+*/
 void AddToList(char *s1, char* s2)
 {
 	int tw1, tw2;
@@ -1402,9 +1408,9 @@ void MakeList(void)
 	}
 }
 
-/************************************************************************
+/*
   X Error Handler
-************************************************************************/
+*/
 static int
 ErrorHandler(Display *d, XErrorEvent *event)
 {
