@@ -1,18 +1,4 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
+/* -*-c-*- */
 #include "libs/fvwmlib.h"
 #include <fvwm/fvwm.h>
 #include <libs/vpacket.h>
@@ -51,13 +37,13 @@ struct Item
   struct Item* next;
 };
 
-/*************************************************************************
+/*
  *
  * Subroutine Prototypes
  *
- *************************************************************************/
+ */
 void Loop(int *fd);
-void DeadPipe(int nonsense) __attribute__((noreturn));
+RETSIGTYPE DeadPipe(int nonsense) __attribute__((noreturn));
 void process_message(unsigned long type, unsigned long *body);
 void PixmapDrawWindow(int h, int w);
 void DrawItems(Drawable d, int x, int y, int w, int h);
