@@ -84,6 +84,8 @@ typedef struct pager_window
   int pager_view_y;
   int pager_view_width;
   int pager_view_height;
+  int icon_view_x;
+  int icon_view_y;
   int icon_view_width;
   int icon_view_height;
 
@@ -200,5 +202,5 @@ void HandleEnterNotify(XEvent *Event);
 void HandleExpose(XEvent *Event);
 void MoveStickyWindows(void);
 void MapBalloonWindow(PagerWindow *t, Bool is_icon_view);
-void UnmapBalloonWindow();
+void UnmapBalloonWindow(void);
 void DrawInBalloonWindow(int i);
