@@ -34,6 +34,8 @@
 #include "libs/Picture.h"
 #include "libs/PictureGraphics.h"
 #include "libs/safemalloc.h"
+#include "libs/charmap.h"
+#include "libs/modifiers.h"
 
 #include "FvwmProxy.h"
 
@@ -41,6 +43,7 @@
 
 /* defaults for things we put in a configuration file */
 
+#define PROXY_KEY_POLLING	True
 #define PROXY_MOVE		False	/* move window when proxy is dragged */
 #define PROXY_WIDTH		180
 #define PROXY_HEIGHT		60
@@ -50,18 +53,10 @@
 
 #define STARTUP_DEBUG		False	/* store output before log is opened */
 
-#if 0
-#define CMD_SHOW		"Function FvwmProxyShowFunc"
-#define CMD_HIDE		"Function FvwmProxyHideFunc"
-#define CMD_ABORT		"Function FvwmProxyAbortFunc"
-#define CMD_SELECT		"Function FvwmProxySelectFunc"
-#define CMD_MARK		"Function FvwmProxyMarkFunc"
-#else
 #define CMD_SELECT		"WindowListFunc $[w.id]"
 #define CMD_CLICK1		"Raise"
 #define CMD_CLICK3		"Lower"
 #define CMD_DEFAULT		"Nop"
-#endif
 
 /* ---------------------------- local macros -------------------------------- */
 
@@ -87,7 +82,6 @@ static GC sh_gc;
 static GC miniIconGC;
 static Window rootWindow;
 static Window focusWindow;
-static FILE *errorFile;
 static XTextProperty windowName;
 static int deskNumber=0;
 static int mousex,mousey;
@@ -98,6 +92,9 @@ static ProxyWindow *startProxy=NULL;
 static ProxyWindow *enterProxy=NULL;
 static XGCValues xgcv;
 static int are_windows_shown = 0;
+static int watching_modifiers = 0;
+static unsigned int held_modifiers=0;
+static unsigned int watched_modifiers=0;
 static FlocaleWinString *FwinString;
 
 static int cset_normal = 0;
@@ -112,7 +109,6 @@ static int proxyHeight=PROXY_HEIGHT;
 static int proxySeparation=PROXY_SEPARATION;
 
 static char commandBuffer[256];
-static char *logfilename=NULL;
 #if 0
 static char *show_command;
 static char *hide_command;
@@ -121,10 +117,6 @@ static char *select_command;
 static char *abort_command;
 #endif
 
-#if STARTUP_DEBUG
-static char startupText[10000];
-#endif
-
 typedef enum
 {
 	PROXY_ACTION_SELECT = 0,
@@ -133,12 +125,14 @@ typedef enum
 	PROXY_ACTION_ABORT,
 	PROXY_ACTION_MARK,
 	PROXY_ACTION_UNMARK,
+	PROXY_ACTION_MODIFIER_RELEASE,
 	/* this one *must* be last */
 	PROXY_ACTION_CLICK,
-	PROXY_ACTION_LAST = PROXY_ACTION_CLICK + NUMBER_OF_BUTTONS
+	PROXY_ACTION_LAST = PROXY_ACTION_CLICK +
+	NUMBER_OF_EXTENDED_MOUSE_BUTTONS
 } proxy_action_t;
 
-char *ClickAction[PROXY_ACTION_LAST];
+char *action_list[PROXY_ACTION_LAST];
 
 static int (*originalXErrorHandler)(Display *,XErrorEvent *);
 static int (*originalXIOErrorHandler)(Display *);
@@ -156,64 +150,76 @@ static void LinkAction(char *string)
 	{
 		int b;
 		int i;
-		i = sscanf(string, "%d", &b);
-		if (i > 0 && b >=1 && b <= NUMBER_OF_MOUSE_BUTTONS)
+		i = sscanf(token + 5, "%d", &b);
+		if (i > 0 && b >=1 && b <= NUMBER_OF_EXTENDED_MOUSE_BUTTONS)
 		{
-			if (ClickAction[PROXY_ACTION_CLICK + b - 1] != NULL)
+			if (action_list[PROXY_ACTION_CLICK + b - 1] != NULL)
 			{
-				free(ClickAction[PROXY_ACTION_CLICK + b - 1]);
+				free(action_list[PROXY_ACTION_CLICK + b - 1]);
 			}
-			ClickAction[PROXY_ACTION_CLICK + b - 1] =
+			action_list[PROXY_ACTION_CLICK + b - 1] =
 				safestrdup(string);
 		}
 	}
-	else if(StrEquals(token, "Select"))
+	else if (StrEquals(token, "Select"))
 	{
-		if (ClickAction[PROXY_ACTION_SELECT] != NULL)
+		if (action_list[PROXY_ACTION_SELECT] != NULL)
 		{
-			free(ClickAction[PROXY_ACTION_SELECT]);
+			free(action_list[PROXY_ACTION_SELECT]);
 		}
-		ClickAction[PROXY_ACTION_SELECT] = safestrdup(string);
+		action_list[PROXY_ACTION_SELECT] = safestrdup(string);
 	}
-	else if(StrEquals(token, "Show"))
+	else if (StrEquals(token, "Show"))
 	{
-		if (ClickAction[PROXY_ACTION_SHOW] != NULL)
+		if (action_list[PROXY_ACTION_SHOW] != NULL)
 		{
-			free(ClickAction[PROXY_ACTION_SHOW]);
+			free(action_list[PROXY_ACTION_SHOW]);
 		}
-		ClickAction[PROXY_ACTION_SHOW] = safestrdup(string);
+		action_list[PROXY_ACTION_SHOW] = safestrdup(string);
 	}
-	else if(StrEquals(token, "Hide"))
+	else if (StrEquals(token, "Hide"))
 	{
-		if (ClickAction[PROXY_ACTION_HIDE] != NULL)
+		if (action_list[PROXY_ACTION_HIDE] != NULL)
 		{
-			free(ClickAction[PROXY_ACTION_HIDE]);
+			free(action_list[PROXY_ACTION_HIDE]);
 		}
-		ClickAction[PROXY_ACTION_HIDE] = safestrdup(string);
+		action_list[PROXY_ACTION_HIDE] = safestrdup(string);
 	}
-	else if(StrEquals(token, "Abort"))
+	else if (StrEquals(token, "Abort"))
 	{
-		if (ClickAction[PROXY_ACTION_ABORT] != NULL)
+		if (action_list[PROXY_ACTION_ABORT] != NULL)
 		{
-			free(ClickAction[PROXY_ACTION_ABORT]);
+			free(action_list[PROXY_ACTION_ABORT]);
 		}
-		ClickAction[PROXY_ACTION_ABORT] = safestrdup(string);
+		action_list[PROXY_ACTION_ABORT] = safestrdup(string);
 	}
-	else if(StrEquals(token, "Mark"))
+	else if (StrEquals(token, "Mark"))
 	{
-		if (ClickAction[PROXY_ACTION_MARK] != NULL)
+		if (action_list[PROXY_ACTION_MARK] != NULL)
 		{
-			free(ClickAction[PROXY_ACTION_MARK]);
+			free(action_list[PROXY_ACTION_MARK]);
 		}
-		ClickAction[PROXY_ACTION_MARK] = safestrdup(string);
+		action_list[PROXY_ACTION_MARK] = safestrdup(string);
 	}
-	else if(StrEquals(token, "Unmark"))
+	else if (StrEquals(token, "Unmark"))
 	{
-		if (ClickAction[PROXY_ACTION_UNMARK] != NULL)
+		if (action_list[PROXY_ACTION_UNMARK] != NULL)
 		{
-			free(ClickAction[PROXY_ACTION_UNMARK]);
+			free(action_list[PROXY_ACTION_UNMARK]);
 		}
-		ClickAction[PROXY_ACTION_UNMARK] = safestrdup(string);
+		action_list[PROXY_ACTION_UNMARK] = safestrdup(string);
+	}
+	else if (StrEquals(token, "ModifierRelease"))
+	{
+		token = PeekToken(string, &string);
+
+		if (action_list[PROXY_ACTION_MODIFIER_RELEASE] != NULL)
+		{
+			free(action_list[PROXY_ACTION_MODIFIER_RELEASE]);
+		}
+
+		modifiers_string_to_modmask(token,&watched_modifiers);
+		action_list[PROXY_ACTION_MODIFIER_RELEASE] = safestrdup(string);
 	}
 
 	return;
@@ -241,23 +247,20 @@ static Bool parse_options(void)
 	int m;
 	char *tline;
 
-#if 0
-	show_command = safestrdup(CMD_SHOW);
-	hide_command = safestrdup(CMD_HIDE);
-	abort_command = safestrdup(CMD_ABORT);
-	mark_command = safestrdup(CMD_MARK);
-	select_command = safestrdup(CMD_SELECT);
-#endif
-	memset(ClickAction, 0, sizeof(ClickAction));
-	ClickAction[PROXY_ACTION_SELECT] = strdup(CMD_SELECT);
-	ClickAction[PROXY_ACTION_CLICK + 0] = strdup(CMD_CLICK1);
-	if (NUMBER_OF_MOUSE_BUTTONS > 2)
+	memset(action_list, 0, sizeof(action_list));
+	action_list[PROXY_ACTION_SELECT] = strdup(CMD_SELECT);
+	action_list[PROXY_ACTION_CLICK + 0] = strdup(CMD_CLICK1);
+	if (NUMBER_OF_EXTENDED_MOUSE_BUTTONS > 2)
 	{
-		ClickAction[PROXY_ACTION_CLICK + 2] = strdup(CMD_CLICK3);
+		action_list[PROXY_ACTION_CLICK + 2] = strdup(CMD_CLICK3);
+	}
+	for (m=0;m<PROXY_ACTION_LAST;m++)
+	{
+		if (action_list[m]==NULL)
+		{
+			action_list[m] = strdup(CMD_DEFAULT);
+		}
 	}
-	for(m=0;m<PROXY_ACTION_LAST;m++)
-		if(ClickAction[m]==NULL)
-			ClickAction[m] = strdup(CMD_DEFAULT);
 
 	InitGetConfigLine(fd, CatString3("*", MyName, 0));
 	for (GetConfigLine(fd, &tline); tline != NULL;
@@ -281,15 +284,9 @@ static Bool parse_options(void)
 		}
 
 		/* dump leading whitespace */
-		while(*tline==' ' || *tline=='\t')
+		while (*tline==' ' || *tline=='\t')
 			tline++;
-#if STARTUP_DEBUG
-		strcat(startupText,resource);
-		strcat(startupText," |");
-		strcat(startupText,tline);
-		strcat(startupText,"|\n");
-#endif
-		if(!strncasecmp(resource,"Action",6))
+		if (!strncasecmp(resource,"Action",6))
 		{
 			LinkAction(tline);
 		}
@@ -315,14 +312,6 @@ static Bool parse_options(void)
 			}
 			font_name = safestrdup(tline);
 		}
-		else if (StrEquals(resource, "LogFile"))
-		{
-			if (logfilename != NULL)
-			{
-				free(logfilename);
-			}
-			logfilename = safestrdup(tline);
-		}
 		else if (StrEquals(resource, "ShowMiniIcons"))
 		{
 			showMiniIcons = ParseToggleArgument(tline, NULL, 0, 1);
@@ -350,46 +339,6 @@ static Bool parse_options(void)
 			if (sscanf(tline, "%d", &proxySeparation) < 1)
 				proxySeparation=False;
 		}
-#if 0
-		else if (StrEquals(resource, "ShowCommand"))
-		{
-			parse_cmd(&show_command, next);
-		}
-		else if (StrEquals(resource, "HideCommand"))
-		{
-			parse_cmd(&hide_command, next);
-		}
-		else if (StrEquals(resource, "AbortCommand"))
-		{
-			parse_cmd(&abort_command, next);
-		}
-		else if (StrEquals(resource, "MarkCommand"))
-		{
-			parse_cmd(&mark_command, next);
-		}
-		else if (StrEquals(resource, "SelectCommand"))
-		{
-			parse_cmd(&select_command, next);
-		}
-
-		else if (StrEquals(resource, "ProxyGeometry"))
-		{
-			flags = FScreenParseGeometry(
-				tline, &g_x, &g_y, &width, &height);
-			if (flags & WidthValue)
-			{
-				/*!!!*/
-			}
-			if (flags & HeightValue)
-			{
-				/*!!!*/
-			}
-			if (flags & (XValue | YValue))
-			{
-				/*!!!error*/
-			}
-		}
-#endif
 
 		free(resource);
 	}
@@ -446,30 +395,22 @@ static int myXErrorHandler(Display *display,XErrorEvent *error_event)
 	XGetErrorDatabaseText(display,"XRequest",
 		request_number,buffer,function,messagelen);
 
-	fprintf(errorFile,"non-fatal X error as follows, display 0x%x"
+	fprintf(stderr, "non-fatal X error as follows, display 0x%x"
 		" op %d:%d \"%s\" serial %u error %d\n",
 		(unsigned int)display,
 		error_event->request_code,error_event->minor_code,
 		function,(unsigned int)error_event->serial,
 		error_event->error_code);
-#if 0
-	/* !!!calling X routines from error handlers is not allowed! */
-	XGetErrorText(display,error_event->error_code,buffer,messagelen);
-	fprintf(errorFile,"  %s\n",buffer);
-#endif
 
 	return 0;
 }
 
 static int myXIOErrorHandler(Display *display)
 {
-	fprintf(errorFile,"fatal IO Error on display 0x%x\n",
+	fprintf(stderr, "fatal IO Error on display 0x%x\n",
 		(unsigned int)display);
-
 	originalXIOErrorHandler(display);
 
-	fprintf(errorFile,"original X IO handler should not have returned\n");
-
 	/* should never get this far */
 	return 0;
 }
@@ -494,8 +435,10 @@ static ProxyWindow *FindProxy(Window window)
 
 	for (proxy=firstProxy; proxy != NULL; proxy=proxy->next)
 	{
-		if(proxy->proxy==window || proxy->window==window)
+		if (proxy->proxy==window || proxy->window==window)
+		{
 			return proxy;
+		}
 	}
 
 	return NULL;
@@ -506,7 +449,7 @@ static void DrawPicture(
 {
 	FvwmRenderAttributes fra;
 
-	if(!picture || picture->picture == None)
+	if (!picture || picture->picture == None)
 		return;
 
 	fra.mask = FRAM_DEST_IS_A_WINDOW;
@@ -529,8 +472,10 @@ static void DrawWindow(
 	FvwmPicture *picture = &proxy->picture;
 	int drawMiniIcon=(showMiniIcons && proxy->picture.picture != None);
 
-	if (!proxy)
+	if (!proxy || proxy->proxy == None)
+	{
 		return;
+	}
 
 	x=0;
 	y=0;
@@ -538,12 +483,16 @@ static void DrawWindow(
 	h=proxy->proxyh;
 
 	texty=(h+ Ffont->ascent - Ffont->descent)/2;	/* center */
-	if(drawMiniIcon)
+	if (drawMiniIcon)
+	{
 		texty+=8;				/* half icon height */
+	}
 
 	maxy=h-Ffont->descent-4;
-	if(texty>maxy)
+	if (texty>maxy)
+	{
 		texty=maxy;
+	}
 
 	cset = (proxy==selectProxy) ? cset_select : cset_normal;
 	XSetForeground(dpy,fg_gc,Colorset[cset].fg);
@@ -562,8 +511,11 @@ static void DrawWindow(
 		int text_width = FlocaleTextWidth(
 			Ffont,proxy->iconname,strlen(proxy->iconname));
 		int edge=(w-text_width)/2;
-		if(edge<5)
+
+		if (edge<5)
+		{
 			edge=5;
+		}
 
 		FwinString->str = proxy->iconname;
 		FwinString->win = proxy->proxy;
@@ -578,8 +530,10 @@ static void DrawWindow(
 		}
 		FlocaleDrawString(dpy, Ffont, FwinString, 0);
 	}
-	if(drawMiniIcon)
+	if (drawMiniIcon)
+	{
 		DrawPicture(proxy->proxy, (w-16)/2, 4, picture, cset);
+	}
 }
 
 static void DrawProxy(ProxyWindow *proxy)
@@ -596,7 +550,7 @@ static void DrawProxyBackground(ProxyWindow *proxy)
 {
 	int cset;
 
-	if (proxy == NULL)
+	if (proxy == NULL || proxy->proxy == None)
 	{
 		return;
 	}
@@ -629,9 +583,11 @@ static void OpenOneWindow(ProxyWindow *proxy)
 	if (proxy->proxy == None)
 	{
 		long eventMask=ButtonPressMask|ExposureMask|ButtonMotionMask;
-		if(enterSelect)
-			eventMask|=EnterWindowMask;
 
+		if (enterSelect)
+		{
+			eventMask|=EnterWindowMask;
+		}
 		attributes.override_redirect = True;
 		proxy->proxy = XCreateWindow(
 			dpy, rootWindow, proxy->proxyx, proxy->proxyy,
@@ -707,12 +663,12 @@ static Bool SortProxiesOnce(void)
 		x1=proxy->proxyx;
 		x2=proxy->next->proxyx;
 
-		if( x1>x2 || (x1==x2 && proxy->proxyy > proxy->next->proxyy) )
+		if ( x1>x2 || (x1==x2 && proxy->proxyy > proxy->next->proxyy) )
 		{
 			change=True;
 			next=proxy->next;
 
-			if(lastProxy)
+			if (lastProxy)
 				lastProxy->next=next;
 			else
 				firstProxy=next;
@@ -752,14 +708,13 @@ static Bool AdjustOneWindow(ProxyWindow *proxy)
 	{
 		int dx=abs(proxy->proxyx-other->proxyx);
 		int dy=abs(proxy->proxyy-other->proxyy);
-		if(dx<(proxyWidth+proxySeparation) &&
-		   dy<proxyHeight+proxySeparation )
+		if (dx<(proxyWidth+proxySeparation) &&
+				dy<proxyHeight+proxySeparation )
 		{
 			rc = True;
-			if(proxyWidth-dx<proxyHeight-dy)
+			if (proxyWidth-dx<proxyHeight-dy)
 			{
-				fprintf(errorFile,"Adjust X\n");
-				if(proxy->proxyx<other->proxyx)
+				if (proxy->proxyx<other->proxyx)
 				{
 					other->proxyx=
 						proxy->proxyx+ proxy->proxyw+
@@ -774,8 +729,7 @@ static Bool AdjustOneWindow(ProxyWindow *proxy)
 			}
 			else
 			{
-				fprintf(errorFile,"Adjust y\n");
-				if(proxy->proxyy<other->proxyy)
+				if (proxy->proxyy<other->proxyy)
 				{
 					other->proxyy=
 						proxy->proxyy+ proxy->proxyh+
@@ -798,7 +752,7 @@ static void AdjustWindows(void)
 {
 	Bool collision=True;
 
-	while(collision == True)
+	while (collision == True)
 	{
 		ProxyWindow *proxy;
 
@@ -904,7 +858,7 @@ static void DestroyWindow(Window w)
 	for (proxy=firstProxy, prev = NULL; proxy != NULL;
 		prev = proxy, proxy=proxy->next)
 	{
-		if(proxy->proxy==w || proxy->window==w)
+		if (proxy->proxy==w || proxy->window==w)
 			break;
 	}
 	if (proxy == NULL)
@@ -962,6 +916,33 @@ static void IconifyWindow(Window w, int is_iconified)
 	return;
 }
 
+static unsigned int GetModifiers(void)
+{
+	Window root_return, child_return;
+	int root_x_return, root_y_return;
+	int win_x_return, win_y_return;
+	unsigned int mask_return;
+
+	if (FQueryPointer(
+			dpy,rootWindow,&root_return,
+			&child_return,
+			&root_x_return,&root_y_return,
+			&win_x_return,&win_y_return,
+			&mask_return) == False)
+	{
+		/* pointer is on another screen - ignore */
+	}
+
+	/* mask_return
+		0x01	shift
+		0x02	caplock
+		0x04	ctrl
+		0x08	alt
+		0x40	logo
+	*/
+	return mask_return;
+}
+
 static void StartProxies(void)
 {
 	if (are_windows_shown)
@@ -969,10 +950,14 @@ static void StartProxies(void)
 		return;
 	}
 
+	held_modifiers=GetModifiers();
 	enterProxy=NULL;
 	selectProxy=NULL;
 
-	send_command_to_fvwm(ClickAction[PROXY_ACTION_SHOW], None);
+	if(action_list[PROXY_ACTION_MODIFIER_RELEASE])
+		watching_modifiers=1;
+
+	send_command_to_fvwm(action_list[PROXY_ACTION_SHOW], None);
 	are_windows_shown = 1;
 	CloseWindows();
 	ReshuffleWindows();
@@ -1001,10 +986,10 @@ static void MarkProxy(ProxyWindow *new_proxy)
 		}
 	}
 	if (old_proxy != NULL)
-		send_command_to_fvwm(ClickAction[PROXY_ACTION_UNMARK],
+		send_command_to_fvwm(action_list[PROXY_ACTION_UNMARK],
 				old_proxy->window);
 	if (selectProxy != NULL)
-		send_command_to_fvwm(ClickAction[PROXY_ACTION_MARK],
+		send_command_to_fvwm(action_list[PROXY_ACTION_MARK],
 				selectProxy->window);
 
 	return;
@@ -1027,14 +1012,14 @@ static void SelectProxy(void)
 	ProxyWindow *proxy;
 
 	HideProxies();
-	if(selectProxy)
-		send_command_to_fvwm(ClickAction[PROXY_ACTION_SELECT],
+	if (selectProxy)
+		send_command_to_fvwm(action_list[PROXY_ACTION_SELECT],
 				selectProxy->window);
 
-	send_command_to_fvwm(ClickAction[PROXY_ACTION_HIDE], None);
+	send_command_to_fvwm(action_list[PROXY_ACTION_HIDE], None);
 
-	for(proxy=firstProxy; proxy != NULL; proxy=proxy->next)
-		if(proxy==selectProxy)
+	for (proxy=firstProxy; proxy != NULL; proxy=proxy->next)
+		if (proxy==selectProxy)
 		{
 			startProxy=proxy;
 			break;
@@ -1045,10 +1030,10 @@ static void SelectProxy(void)
 	return;
 }
 
-static void AbortProxies(boid)
+static void AbortProxies(void)
 {
 	HideProxies();
-	send_command_to_fvwm(ClickAction[PROXY_ACTION_ABORT], None);
+	send_command_to_fvwm(action_list[PROXY_ACTION_ABORT], None);
 	selectProxy = NULL;
 
 	return;
@@ -1125,10 +1110,10 @@ static void ProcessMessage(FvwmPacket* packet)
 		}
 		break;
 	case M_NEW_DESK:
-		if(deskNumber!=body[0])
+		if (deskNumber!=body[0])
 		{
 			deskNumber=body[0];
-			if(are_windows_shown)
+			if (are_windows_shown)
 			{
 				CloseWindows();
 				OpenWindows();
@@ -1155,8 +1140,6 @@ static void ProcessMessage(FvwmPacket* packet)
 	case M_FOCUS_CHANGE:
 	{
 		focusWindow=bh->w;
-/*		fprintf(errorFile,"M_FOCUS_CHANGE 0x%x\n",(int)focusWindow);
-*/
 	}
 	case M_STRING:
 	{
@@ -1165,10 +1148,9 @@ static void ProcessMessage(FvwmPacket* packet)
 		char *next;
 		int prev;
 
-		fprintf(errorFile, "M_STRING \"%s\"\n", message);
 		token = PeekToken(message, &next);
 		prev=(StrEquals(token, "Prev"));
-		if(StrEquals(token, "Next") || prev)
+		if (StrEquals(token, "Next") || prev)
 		{
 			ProxyWindow *lastSelect=selectProxy;
 			ProxyWindow *newSelect=selectProxy;
@@ -1178,37 +1160,37 @@ static void ProcessMessage(FvwmPacket* packet)
 			if (!are_windows_shown)
 				StartProxies();
 
-			if(startProxy && startProxy->desk==deskNumber)
+			if (startProxy && startProxy->desk==deskNumber)
 			{
 				newSelect=startProxy;
 				startProxy=NULL;
 			}
 			else
 			{
-				if(newSelect)
+				if (newSelect)
 				{
-					if(prev)
+					if (prev)
 						newSelect=newSelect->prev;
 					else
 						newSelect=newSelect->next;
 				}
-				if(!newSelect)
+				if (!newSelect)
 					newSelect=first;
-				while(newSelect!=lastSelect &&
-					newSelect->desk!=deskNumber)
+				while (newSelect!=lastSelect &&
+						newSelect->desk!=deskNumber)
 				{
-					if(prev)
+					if (prev)
 						newSelect=newSelect->prev;
 					else
 						newSelect=newSelect->next;
-					if(!newSelect && lastSelect)
+					if (!newSelect && lastSelect)
 						newSelect=first;
 				}
 			}
 
 			MarkProxy(newSelect);
 		}
-		else if(StrEquals(token, "Circulate"))
+		else if (StrEquals(token, "Circulate"))
 		{
 			Window w;
 
@@ -1220,32 +1202,33 @@ static void ProcessMessage(FvwmPacket* packet)
 
 			strcpy(commandBuffer,next);
 			strcat(commandBuffer," SendToModule FvwmProxy Mark");
-
-			fprintf(errorFile, "0x%x:0x%x Circulate \"%s\"\n",
-				(int)selectProxy,(int)w,commandBuffer);
-			if(next)
+			if (next)
 				SendFvwmPipe(fd,commandBuffer,w);
 		}
-		else if(StrEquals(token, "Show"))
+		else if (StrEquals(token, "Show"))
 		{
 			StartProxies();
 		}
-		else if(StrEquals(token, "Hide"))
+		else if (StrEquals(token, "Hide"))
 		{
 			SelectProxy();
 		}
-		else if(StrEquals(token, "ShowToggle"))
+		else if (StrEquals(token, "ShowToggle"))
 		{
-			if(are_windows_shown)
+			if (are_windows_shown)
+			{
 				SelectProxy();
+			}
 			else
+			{
 				StartProxies();
+			}
 		}
-		else if(StrEquals(token, "Abort"))
+		else if (StrEquals(token, "Abort"))
 		{
-			AbortProxies(True);
+			AbortProxies();
 		}
-		else if(StrEquals(token, "Mark"))
+		else if (StrEquals(token, "Mark"))
 		{
 #if 0
 			Window w;
@@ -1263,9 +1246,6 @@ static void ProcessMessage(FvwmPacket* packet)
 			{
 				focusWindow=bh->w;
 				proxy = FindProxy(bh->w);
-				fprintf(errorFile,
-					"Mark proxy 0x%x win 0x%x\n",
-					(int)proxy,(int)bh->w);
 			}
 			MarkProxy(proxy);
 		}
@@ -1287,7 +1267,7 @@ static void ProcessMessage(FvwmPacket* packet)
 	}
 	}
 
-	fflush(errorFile);
+	return;
 }
 
 static int My_XNextEvent(Display *dpy,XEvent *event)
@@ -1298,7 +1278,7 @@ static int My_XNextEvent(Display *dpy,XEvent *event)
 	timevalue.tv_sec = 0;
 	timevalue.tv_usec = 100000;
 
-	if(FPending(dpy))
+	if (FPending(dpy))
 	{
 		FNextEvent(dpy,event);
 		return 1;
@@ -1308,24 +1288,23 @@ static int My_XNextEvent(Display *dpy,XEvent *event)
 	FD_SET(x_fd,&in_fdset);
 	FD_SET(fd[1],&in_fdset);
 
-	if( fvwmSelect(fd_width, &in_fdset, 0, 0, timeout) > 0)
+	if ( fvwmSelect(fd_width, &in_fdset, 0, 0, timeout) > 0)
 	{
-		if(FD_ISSET(x_fd, &in_fdset))
+		if (FD_ISSET(x_fd, &in_fdset))
 		{
-			if(FPending(dpy))
+			if (FPending(dpy))
 			{
 				FNextEvent(dpy,event);
 				return 1;
 			}
 		}
 
-		if(FD_ISSET(fd[1], &in_fdset))
+		if (FD_ISSET(fd[1], &in_fdset))
 		{
 			FvwmPacket* packet = ReadFvwmPacket(fd[1]);
-			if(!packet)
+			if (!packet)
 			{
-				fprintf(errorFile,"\nNULL packet: exiting\n");
-				fflush(errorFile);
+				fprintf(stderr, "\nNULL packet: exiting\n");
 				exit(0);
 			}
 
@@ -1355,44 +1334,29 @@ static void DispatchEvent(XEvent *pEvent)
 		break;
 	case ButtonPress:
 		proxy = FindProxy(window);
-		if(proxy)
+		if (proxy)
 		{
-#if 0
-			/* TODO setup from Fvwm config */
-			if(pEvent->xbutton.button==Button1)
-				XRaiseWindow(dpy,proxy->window);
-			else if(pEvent->xbutton.button==Button3)
-				XLowerWindow(dpy,proxy->window);
-#else
 			int button=pEvent->xbutton.button;
-			if(button >= 1 && button<=NUMBER_OF_MOUSE_BUTTONS)
+			if (button >= 1 &&
+			    button <= NUMBER_OF_EXTENDED_MOUSE_BUTTONS)
 			{
-				fprintf(errorFile,"SendFvwmPipe %s 0x%x %d\n",
-					ClickAction[PROXY_ACTION_CLICK+
-								button-1],
-					(int)proxy->window,button);
-				SendFvwmPipe(fd,
-					ClickAction[PROXY_ACTION_CLICK+
-								button-1],
+				SendFvwmPipe(
+					fd, action_list
+						[PROXY_ACTION_CLICK + button-1],
 					proxy->window);
 			}
-
-#endif
 		}
 		mousex=pEvent->xbutton.x_root;
 		mousey=pEvent->xbutton.y_root;
 		break;
 	case MotionNotify:
 		proxy = FindProxy(window);
-		fprintf(errorFile,"MotionNotify %4d,%4d\n",
-			pEvent->xmotion.x_root,pEvent->xmotion.y_root);
 		dx=pEvent->xbutton.x_root-mousex;
 		dy=pEvent->xbutton.y_root-mousey;
-		if(proxy && proxyMove)
+		if (proxy && proxyMove)
 		{
 			sprintf(commandBuffer,"Silent Move w%dp w%dp",dx,dy);
 			SendText(fd,commandBuffer,proxy->window);
-			fprintf(errorFile,">>> %s\n",commandBuffer);
 		}
 
 		mousex=pEvent->xbutton.x_root;
@@ -1414,12 +1378,11 @@ static void DispatchEvent(XEvent *pEvent)
 		}
 		break;
 	default:
-		fprintf(errorFile,"Unrecognized XEvent %d\n",
-			pEvent->xany.type);
+		fprintf(stderr, "Unrecognized XEvent %d\n", pEvent->xany.type);
 		break;
 	}
 
-	fflush(errorFile);
+	return;
 }
 
 static void Loop(int *fd)
@@ -1427,12 +1390,27 @@ static void Loop(int *fd)
 	XEvent event;
 	long result;
 
-	while(1)
+	while (1)
 	{
-		if((result=My_XNextEvent(dpy,&event))==1)
+		if ((result=My_XNextEvent(dpy,&event))==1)
 		{
 			DispatchEvent(&event);
 		}
+
+#if PROXY_KEY_POLLING
+		if(are_windows_shown && watching_modifiers)
+		{
+			unsigned int mask_return=GetModifiers();
+			if(!(mask_return&watched_modifiers))
+			{
+				watching_modifiers=0;
+				send_command_to_fvwm(
+					action_list
+					[PROXY_ACTION_MODIFIER_RELEASE],
+					None);
+			}
+		}
+#endif
 	}
 }
 
@@ -1442,14 +1420,11 @@ int main(int argc, char **argv)
 {
 	char *titles[1];
 
-#if STARTUP_DEBUG
-	startupText[0]=0;
-#endif
-
 	if (argc < 6)
 	{
-		fprintf(stderr,"FvwmProxy should only be executed by fvwm!\n");
-		fflush(errorFile);
+		fprintf(
+			stderr,
+			"FvwmProxy should only be executed by fvwm!\n");
 		exit(1);
 	}
 
@@ -1468,7 +1443,7 @@ int main(int argc, char **argv)
 		exit (1);
 	}
 	titles[0]="FvwmProxy";
-	if(XStringListToTextProperty(titles,1,&windowName) == 0)
+	if (XStringListToTextProperty(titles,1,&windowName) == 0)
 	{
 		fprintf(stderr,"Proxy_CreateBar() could not allocate space"
 			" for window title");
@@ -1498,19 +1473,6 @@ int main(int argc, char **argv)
 
 	if (parse_options() == False)
 		exit(1);
-
-	if(!logfilename)
-		logfilename="/dev/null";
-	errorFile=fopen(logfilename,"a");
-
-	fprintf(errorFile,"FvwmProxy >>>>>>>>> STARTUP\n");
-	fflush(errorFile);
-#if STARTUP_DEBUG
-	fprintf(errorFile,"startup:\n%s-----\n",startupText);
-#endif
-	fprintf(errorFile,"started\n");
-	fflush(errorFile);
-
 	if ((Ffont = FlocaleLoadFont(dpy, font_name, MyName)) == NULL)
 	{
 		fprintf(stderr,"%s: Couldn't load font. Exiting!\n", MyName);
