@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,12 +14,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "config.h"
+
 #include "Tools.h"
 
 
-/***********************************************/
-/* Fonction pour HScrollBar                    */
-/***********************************************/
+/*
+ * Fonction pour HScrollBar
+ */
 void DrawThumbH(struct XObj *xobj, XEvent *evp)
 {
   int x,y,w,h;
