@@ -178,7 +178,7 @@ Bool startButtonPressed = FALSE;
 ButtonArray buttons;
 List windows;
 
-char *ClickAction[max(NUMBER_OF_MOUSE_BUTTONS, 3)] =
+char *ClickAction[max(NUMBER_OF_EXTENDED_MOUSE_BUTTONS, 3)] =
 {
   DEFAULT_CLICK1,
   DEFAULT_CLICK2,
@@ -269,7 +269,7 @@ int main(int argc, char **argv)
   setlocale(LC_TIME, "");
   FGettextInit("FvwmTaskBar", LOCALEDIR, "FvwmTaskBar");
 
-  for (i = 3; i < NUMBER_OF_MOUSE_BUTTONS; i++)
+  for (i = 3; i < NUMBER_OF_EXTENDED_MOUSE_BUTTONS; i++)
   {
     ClickAction[i] = DEFAULT_CLICK_N;
   }
@@ -532,7 +532,6 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 
 	win_border = nb;
 	win_width = nw;
-	win_height = nh;
 	win_has_title = nht;
 	win_title_dir = ntd;
 	win_title_height = nth;
@@ -1388,7 +1387,10 @@ void CheckForTip(int x, int y)
   }
   else {
     ClearAlarm(SHOW_TIP);
-    if (Tip.open) ShowTipWindow(0);
+    if (Tip.open)
+    {
+      ShowTipWindow(0);
+    }
   }
 }
 
@@ -1462,7 +1464,7 @@ void HandleButtonRelease(
 	{
 		ButReleased = ButPressed; /* Avoid race fvwm pipe */
 		if (evp->xbutton.button >= 1 &&
-		    evp->xbutton.button <= NUMBER_OF_MOUSE_BUTTONS)
+		    evp->xbutton.button <= NUMBER_OF_EXTENDED_MOUSE_BUTTONS)
 		{
 			rectangle r;
 			Window tmpw;
@@ -1642,14 +1644,16 @@ void HandleEvents(
 					ItemID(&windows, num));
 		}
 
-		CheckForTip(evp->xmotion.x, evp->xmotion.y);
+		CheckForTip(evp->xcrossing.x, evp->xcrossing.y);
 		break;
 
 	case LeaveNotify:
 		*NewTimestamp = evp->xcrossing.time;
 		ClearAlarm(SHOW_TIP);
 		if (Tip.open)
+		{
 			ShowTipWindow(0);
+		}
 
 		if (AutoHide)
 			SetAlarm(HIDE_TASK_BAR);
@@ -1851,7 +1855,7 @@ void LinkAction(const char *string)
     int i;
 
     i = sscanf(temp + 5, "%d%n", &b, &n);
-    if (i > 0 && b >=1 && b <= NUMBER_OF_MOUSE_BUTTONS)
+    if (i > 0 && b >=1 && b <= NUMBER_OF_EXTENDED_MOUSE_BUTTONS)
     {
       CopyString(&ClickAction[b - 1], temp + 5 + n);
     }
@@ -2266,7 +2270,7 @@ void StartMeUp(void)
     XFree(nametext.value);
   }
 
-   for (i = 1; i <= NUMBER_OF_MOUSE_BUTTONS; i++)
+   for (i = 1; i <= NUMBER_OF_EXTENDED_MOUSE_BUTTONS; i++)
    {
      XGrabButton(dpy,i,AnyModifier,win,True,GRAB_EVENTS,GrabModeAsync,
 		 GrabModeAsync,None,None);
