@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <dirent.h>
 #include <pwd.h>
 #include "libs/ftime.h"
 #include <sys/stat.h>
@@ -83,15 +84,16 @@ int IgnoreOldMail = False;
 int ShowTips = False;
 char *statusfont_string = NULL;
 int last_date = -1;
+Bool using_MailDir = False;
 
-void cool_get_inboxstatus();
+void cool_get_inboxstatus(void);
 
 #define gray_width  8
 #define gray_height 8
 extern unsigned char gray_bits[];
 
-/*                x  y  w  h  tw th open type *text   win */
-TipStruct Tip = { 0, 0, 0, 0,  0, 0,   0,   0, NULL, None };
+/*                x  y  w  h  tw th open type px  py *text   win */
+TipStruct Tip = { 0, 0, 0, 0,  0, 0,   0,   0, 0, 0,  NULL, None };
 
 
 static void CreateOrUpdateGoodyGC(void)
@@ -152,11 +154,35 @@ static void CreateOrUpdateGoodyGC(void)
 
 Bool change_goody_colorset(int cset, Bool force)
 {
-  if (cset < 0 || (cset != tipscolorset && !force))
-    return False;
-  CreateOrUpdateGoodyGC();
+	if (cset < 0)
+	{
+		return False;
+	}
+	if (cset == tipscolorset && Tip.win != None)
+	{
+		char *s;
 
-  return True;
+		if (Tip.text != NULL)
+		{
+			s = safestrdup(Tip.text);
+		}
+		else
+		{
+			s = NULL;
+		}
+		PopupTipWindow(Tip.px, Tip.py, s);
+		if (s != NULL)
+		{
+			free(s);
+		}
+	}
+	if (!force && cset != colorset)
+	{
+		return False;
+	}
+	CreateOrUpdateGoodyGC();
+
+	return True;
 }
 
 static char *goodyopts[] =
@@ -173,6 +199,7 @@ static char *goodyopts[] =
   "IgnoreOldMail",
   "ShowTips",
   "DateFormat",
+  "MailDir",
   NULL
 };
 
@@ -255,6 +282,9 @@ Bool GoodiesParseConfig(char *tline)
 	    do_display_clock = False;
     }
     break;
+  case 12: /* MailDir */
+    using_MailDir = True;
+    break;
   default:
     /* unknow option */
     return False;
@@ -509,7 +539,7 @@ void CreateMailTipWindow()
 
 void RedrawTipWindow(void)
 {
-  /* FIXME: I am sure that we redraw to often */
+  /* FIXME: I am sure that we redraw too often */
   if (Tip.text) {
     FwinString->win = Tip.win;
     FwinString->gc = tipsgc;
@@ -540,6 +570,8 @@ void PopupTipWindow(int px, int py, const char *text)
   int newx, newy;
   Window child;
 
+  Tip.px = px;
+  Tip.py = py;
   if (!ShowTips)
     return;
   if (Tip.win != None)
@@ -651,27 +683,18 @@ void CreateTipWindow(int x, int y, int w, int h)
     pchk = XCreatePixmapFromBitmapData(dpy, Tip.win, (char *)gray_bits,
 				       gray_width, gray_height, 1, 0, 1);
   gcval.stipple = pchk;
-  if (cgc)
-    XChangeGC(dpy, cgc, gcmask, &gcval);
-  else
-    cgc = fvwmlib_XCreateGC(dpy, pmask, gcmask, &gcval);
+  cgc = fvwmlib_XCreateGC(dpy, pmask, gcmask, &gcval);
 
   gcmask = GCForeground | GCBackground | GCGraphicsExposures | GCFillStyle;
   gcval.graphics_exposures = False;
   gcval.fill_style = FillSolid;
   gcval.foreground = 0;
   gcval.background = 0;
-  if (gc0)
-    XChangeGC(dpy, gc0, gcmask, &gcval);
-  else
-    gc0 = fvwmlib_XCreateGC(dpy, pmask, gcmask, &gcval);
+  gc0 = fvwmlib_XCreateGC(dpy, pmask, gcmask, &gcval);
 
   gcval.foreground = 1;
   gcval.background = 1;
-  if (gc1)
-    XChangeGC(dpy, gc1, gcmask, &gcval);
-  else
-    gc1 = fvwmlib_XCreateGC(dpy, pmask, gcmask, &gcval);
+  gc1 = fvwmlib_XCreateGC(dpy, pmask, gcmask, &gcval);
 
   XFillRectangle(dpy, pmask, gc0, 0, 0, w+4, h+4);
   XFillRectangle(dpy, pmask, cgc, 3, 3, w+4, h+4);
@@ -712,7 +735,7 @@ void DestroyTipWindow()
 /* (based on the code of 'coolmail' By Byron C. Darrah */
 /*-----------------------------------------------------*/
 
-void cool_get_inboxstatus()
+void cool_get_inboxstatus_mbox(void)
 {
    static off_t oldsize = 0;
    off_t  newsize;
@@ -754,6 +777,115 @@ void cool_get_inboxstatus()
    oldsize = newsize;
 }
 
+static int f_scandir(const char *dir, struct dirent *** namelist)
+{
+	DIR * f_dir;
+	struct dirent * f_temp;
+	/* 10 is just an arbituary number */
+	int f_count = 0, namelist_size = 10;
+	void * r_ret;
+
+	f_dir = opendir(dir);
+	if (f_dir == NULL)
+		return -1;
+	namelist[0] =
+		(struct dirent **)safemalloc(sizeof(struct dirent *) * 10);
+	do {
+		f_temp = readdir(f_dir);
+		if (f_temp == NULL)
+			break;
+		else if (strcmp(f_temp->d_name, ".") != 0 &&
+			 strcmp(f_temp->d_name, "..") != 0)
+		{
+			if (f_count > namelist_size)
+			{
+				r_ret = saferealloc(
+					(void *)(namelist[0]),
+					sizeof(struct dirent) * (f_count +10));
+				namelist[0] = (struct dirent **)r_ret;
+				namelist_size = f_count + 10;
+			}
+			namelist[0][f_count] = (struct dirent *)safemalloc(
+				sizeof(struct dirent));
+			memcpy(
+				namelist[0][f_count], f_temp,
+				sizeof(struct dirent));
+			f_count++;
+		}
+	} while (1);
+
+	return f_count;
+}
+
+void cool_get_inboxstatus_maildir(void)
+{
+	static int oldsize = 0;
+	int  newsize;
+	struct dirent **newlist;
+	struct dirent **curlist;
+	char * alt_mailpath;
+	int curent, newent;
+
+	alt_mailpath = safemalloc(strlen(mailpath) + strlen("/new") + 1);
+	strcpy(alt_mailpath, mailpath);
+	strcat(alt_mailpath, "/new");
+	newent = f_scandir(alt_mailpath, &newlist);
+	strcpy(alt_mailpath, mailpath);
+	strcat(alt_mailpath, "/cur");
+	curent = f_scandir(alt_mailpath, &curlist);
+	free(alt_mailpath);
+
+	newsize = curent + newent;
+
+	if (newent > 0)
+	{
+		anymail = 1;
+		unreadmail = 1;
+	}
+	else if (curent > 0)
+	{
+		anymail = 1;
+		unreadmail = 0;
+	}
+	else
+	{
+		anymail = 0;
+		unreadmail = 0;
+	}
+	if (newsize > oldsize && unreadmail)
+	{
+		newmail = 1;
+		mailcleared = 0;
+	}
+	else
+	{
+		newmail = 0;
+	}
+
+	oldsize = newsize;
+
+	while(curent--)
+	{
+		free(curlist[curent]);
+	}
+	free(curlist);
+	while(newent--)
+	{
+		free(newlist[newent]);
+	}
+	free(newlist);
+}
+
+void cool_get_inboxstatus()
+{
+	if (using_MailDir)
+	{
+		cool_get_inboxstatus_maildir();
+	} else {
+		cool_get_inboxstatus_mbox();
+	}
+}
+
 /*---------------------------------------------------------------------------*/
 
 void HandleMailClick(XEvent event)
