@@ -182,7 +182,8 @@ void InitAtom(void)
 	ATOM_MOTIF_WM_HINTS = XIA("_MOTIF_WM_HINTS");
 }
 
-void show_usage() {
+void show_usage(void)
+{
 	printf("Usage: hints_test OPTIONS\n");
 	printf("Options:\n");
 	printf("  --mwm-func <names>\n");
@@ -277,7 +278,7 @@ int main(int argc, char **argv)
 			mwm_func_arg = 0;
 			mwm_decor_arg = 0;
 		}
-		if (strcasecmp(argv[i], "--mwm-func") == 0)
+		else if (strcasecmp(argv[i], "--mwm-func") == 0)
 		{
 			ewmh_state_arg = 0;
 			ewmh_type_arg = 0;
